from enum import Enum
from typing import TypeAlias, Union, Any
from PySide6.QtGui import QColor, QRgba64
from PySide6.QtCore import Qt


class Colors(Enum):
    _49ers_red: QColor = QColor(0xAA0000)
    abalone: QColor = QColor(0xD6CFC7)
    abbey: QColor = QColor(0x494F55)
    abbey_white: QColor = QColor(0xEBE5D0)
    abstract_white: QColor = QColor(0xEDE9DD)
    acadia_white: QColor = QColor(0xF4EFE3)
    acid_green: QColor = QColor(0xB0BF1A)
    acorn: QColor = QColor(0xD7A98C)
    acoustic_white: QColor = QColor(0xEFECE1)
    admiral: QColor = QColor(0x051094)
    admiral_blue: QColor = QColor(0x2C3863)
    aegean: QColor = QColor(0x1F456E)
    aegean_blue: QColor = QColor(0x4E6E81)
    aero_blue: QColor = QColor(0xC9FFE5)
    aesthetic_black: QColor = QColor(0x1C1C1E)
    aesthetic_orange: QColor = QColor(0xF4AB6A)
    aesthetic_purple: QColor = QColor(0x502380)
    aesthetic_yellow: QColor = QColor(0xEFD033)
    affair: QColor = QColor(0x6F4685)
    african_violet: QColor = QColor(0xB284BE)
    agreeable_gray: QColor = QColor(0xD1CBC1)
    air_force_blue_raf: QColor = QColor(0x5D8AA8)
    air_force_blue_usaf: QColor = QColor(0x00308F)
    air_superiority_blue: QColor = QColor(0x72A0C1)
    airbnb_red: QColor = QColor(0xFF5A5F)
    aircraft_white: QColor = QColor(0xEDF2F8)
    ajax_red: QColor = QColor(0xD2122E)
    alabama_crimson: QColor = QColor(0x9E1B32)
    alabaster: QColor = QColor(0xEDEAE0)
    alaskan_blue: QColor = QColor(0x6DA9D2)
    albescent_white: QColor = QColor(0xF3DECA)
    alice_blue: QColor = QColor(0xF0F8FF)
    alien_black: QColor = QColor(0x1A2228)
    alizarin_crimson: QColor = QColor(0xE32636)
    alloy_orange: QColor = QColor(0xC35214)
    almond: QColor = QColor(0xEFDECD)
    almost_apricot_red: QColor = QColor(0xE5B39B)
    amaranth: QColor = QColor(0xE52B50)
    amaranth_pink: QColor = QColor(0xE52B50)
    amaranth_purple: QColor = QColor(0xAB274F)
    amaranth_red: QColor = QColor(0xF4364C)
    amazon: QColor = QColor(0x3B7A57)
    amber: QColor = QColor(0xFFBF00)
    american_rose: QColor = QColor(0xFF033E)
    amethyst: QColor = QColor(0x9966CC)
    anchor: QColor = QColor(0x3E424B)
    android_green: QColor = QColor(0xA4C639)
    angels_red: QColor = QColor(0xBA0021)
    anti_flash_white: QColor = QColor(0xF2F3F4)
    antique_brass: QColor = QColor(0xCD9575)
    antique_pewter: QColor = QColor(0x808992)
    antique_white: QColor = QColor(0xFAEBD7)
    antique_white_usa: QColor = QColor(0xEEEAE1)
    anvil_gray: QColor = QColor(0x6B6B6B)
    apple: QColor = QColor(0xA91B0D)
    apple_green: QColor = QColor(0x8DB600)
    apricot: QColor = QColor(0xED820E)
    apricot_orange: QColor = QColor(0xFBCEB1)
    aqua_blue: QColor = QColor(0x0AFFFF)
    aquamarine_blue: QColor = QColor(0x6BCAE2)
    arctic: QColor = QColor(0x82EEFD)
    arctic_blue: QColor = QColor(0xC6E6FB)
    arctic_lime: QColor = QColor(0xD0FF14)
    argentina_blue: QColor = QColor(0x6CB4EE)
    army_green: QColor = QColor(0x4B5320)
    army_uniform: QColor = QColor(0x353F3E)
    arsenal_red: QColor = QColor(0xDB0007)
    arsenic: QColor = QColor(0x3B444B)
    artichoke_green: QColor = QColor(0x8F9779)
    artists_purple: QColor = QColor(0xC71585)
    arylide_yellow: QColor = QColor(0xE9D66B)
    ash: QColor = QColor(0x564C4D)
    ash_brown: QColor = QColor(0x98623C)
    ash_gray: QColor = QColor(0xB2BEB5)
    ash_white: QColor = QColor(0xE9E4D4)
    asparagus: QColor = QColor(0x87A96B)
    asphalt: QColor = QColor(0x0C0404)
    astros_navy: QColor = QColor(0x002D62)
    atomic_tangerine: QColor = QColor(0xFF9966)
    atrium_white: QColor = QColor(0xF1EEE4)
    auburn: QColor = QColor(0xA52A2A)
    auburn_red: QColor = QColor(0xA52A2A)
    audience_anger: QColor = QColor(0xEAF4FC)
    aureolin: QColor = QColor(0xFDEE00)
    autumn_purple: QColor = QColor(0x834468)
    avocado: QColor = QColor(0x568203)
    aztech_purple: QColor = QColor(0x893BFF)
    azure: QColor = QColor(0xF0FFFF)
    azureish_white: QColor = QColor(0xDBE9F4)
    baby_blue: QColor = QColor(0x89CFF0)
    baby_blue_eyes: QColor = QColor(0xA1CAF1)
    baby_orange: QColor = QColor(0xFCBE85)
    baby_pink: QColor = QColor(0xF4C2C2)
    baby_powder: QColor = QColor(0xFEFEFA)
    baby_yellow: QColor = QColor(0xFCEF91)
    baked_bread: QColor = QColor(0xDACBA9)
    baked_potato: QColor = QColor(0xB69E87)
    ballet_slipper: QColor = QColor(0xF79AC0)
    baltimore_ravens_purple: QColor = QColor(0x280353)
    bamboo: QColor = QColor(0xE3DEC6)
    banana: QColor = QColor(0xFFE135)
    barbie_pink: QColor = QColor(0xE0218A)
    bark: QColor = QColor(0x996633)
    barn_red: QColor = QColor(0x7C0A02)
    basalt_black: QColor = QColor(0x4D423E)
    basil: QColor = QColor(0x32612D)
    battleship_gray: QColor = QColor(0x848482)
    bayern_blue: QColor = QColor(0x0066B2)
    bdazzled: QColor = QColor(0x2E5894)
    bdazzled_blue: QColor = QColor(0x2E5894)
    beau_blue: QColor = QColor(0xBCD4E6)
    beaver: QColor = QColor(0x9F8170)
    beer_orange: QColor = QColor(0xF28F1C)
    beeswax: QColor = QColor(0xE9D7AB)
    beige: QColor = QColor(0xF5F5DC)
    beige_linen: QColor = QColor(0xE2DAC6)
    berry: QColor = QColor(0x7A1712)
    berry_blue: QColor = QColor(0x4F86F7)
    best_gray: QColor = QColor(0x969892)
    bills_red: QColor = QColor(0xC60C30)
    birdseed: QColor = QColor(0xE2C28E)
    biscotti: QColor = QColor(0xE3C565)
    bistre: QColor = QColor(0x3D2B1F)
    bitter_chocolate: QColor = QColor(0x9E5B40)
    bitter_lemon: QColor = QColor(0xCAE00D)
    bitter_lime: QColor = QColor(0xBFFF00)
    bittersweet: QColor = QColor(0xFE6F5E)
    bittersweet_shimmer: QColor = QColor(0xBF4F51)
    bittersweet_shimmer_red: QColor = QColor(0xBF4F51)
    black: QColor = QColor(0x000000)
    black_bean: QColor = QColor(0x3D0C02)
    black_blue_ral: QColor = QColor(0x1A1E28)
    black_cat: QColor = QColor(0x413839)
    black_chocolate: QColor = QColor(0x1B1811)
    black_coral: QColor = QColor(0x54626F)
    black_cow: QColor = QColor(0x4C4646)
    black_currant: QColor = QColor(0x540E32)
    black_denim: QColor = QColor(0x191C27)
    black_eel: QColor = QColor(0x463E3F)
    black_grain: QColor = QColor(0x2C2C2A)
    black_gray: QColor = QColor(0x303234)
    black_green_ral: QColor = QColor(0x303D3A)
    black_hole: QColor = QColor(0x060605)
    black_leather_jacket: QColor = QColor(0x253529)
    black_magic: QColor = QColor(0x0B0510)
    black_olive: QColor = QColor(0x3B3C36)
    black_pearl: QColor = QColor(0x0E161A)
    black_plum: QColor = QColor(0x362B32)
    black_raspberry: QColor = QColor(0x451425)
    black_red: QColor = QColor(0x3D2022)
    black_rock: QColor = QColor(0x010127)
    black_russian: QColor = QColor(0x24252B)
    black_shadows: QColor = QColor(0xBFAFB2)
    blackberry: QColor = QColor(0x3A3A38)
    blackish_purple: QColor = QColor(0x291E29)
    blackstrap_molasses: QColor = QColor(0x2B2523)
    blanched_almond: QColor = QColor(0xFFEBCD)
    blazing_yellow: QColor = QColor(0xFEE715)
    bleu_de_france: QColor = QColor(0x318CE7)
    bleu_de_france_blue: QColor = QColor(0x318CE7)
    blood: QColor = QColor(0x710C04)
    blood_red: QColor = QColor(0x660000)
    blue: QColor = QColor(0x0000FF)
    blue_charcoal: QColor = QColor(0x262B2F)
    blue_gray: QColor = QColor(0x98AFC7)
    blue_lilac: QColor = QColor(0x7B679A)
    blue_sapphire: QColor = QColor(0x126180)
    blue_violet: QColor = QColor(0x8A2BE2)
    blue_yonder: QColor = QColor(0x5072A7)
    blueberry: QColor = QColor(0x241571)
    blush: QColor = QColor(0xDE5D83)
    blush_pink: QColor = QColor(0xFEC5E5)
    blush_red: QColor = QColor(0xBC544B)
    boeing_blue: QColor = QColor(0x0039A6)
    bole: QColor = QColor(0x79443B)
    bone: QColor = QColor(0xE3DAC9)
    bosss_jokes: QColor = QColor(0xB0306A)
    bottle_green: QColor = QColor(0x006A4E)
    boysenberry: QColor = QColor(0x630436)
    brandy: QColor = QColor(0xDCB68A)
    brass: QColor = QColor(0xB5A642)
    braves_navy: QColor = QColor(0x13274F)
    brewers_blue: QColor = QColor(0x0A2351)
    brick: QColor = QColor(0x7E2811)
    bright_black: QColor = QColor(0x222024)
    bright_canary_yellow: QColor = QColor(0xFFE41E)
    bright_gray: QColor = QColor(0xE8E9EB)
    bright_maroon: QColor = QColor(0xC32148)
    bright_mint: QColor = QColor(0x4FFFB0)
    bright_pink: QColor = QColor(0xFF007F)
    bright_turquoise: QColor = QColor(0x08E8DE)
    bright_white: QColor = QColor(0xF4F5F0)
    bright_yellow: QColor = QColor(0xFFFD01)
    brilliant_purple: QColor = QColor(0xD399E6)
    brilliant_rose: QColor = QColor(0xFF55A3)
    brilliant_white: QColor = QColor(0xEDF1FE)
    brink: QColor = QColor(0xFF6090)
    british_racing_green: QColor = QColor(0x004225)
    british_standard_bs_4800_10_e_51_yellow: QColor = QColor(0xEDC001)
    broken_white: QColor = QColor(0xEEEBE3)
    broncos_blue: QColor = QColor(0x002244)
    bronze: QColor = QColor(0xB2560D)
    bronze_orange: QColor = QColor(0xCD7F32)
    bronze_yellow: QColor = QColor(0x737000)
    broom_yellow: QColor = QColor(0xDBA400)
    brown_bear: QColor = QColor(0x7F6244)
    brown_beige: QColor = QColor(0xCC8833)
    brown_coffee: QColor = QColor(0x4A2C2A)
    brown_gray: QColor = QColor(0x8D8468)
    brown_metal: QColor = QColor(0xBBADA1)
    brown_oil: QColor = QColor(0x231709)
    brown_red: QColor = QColor(0x922B05)
    brown_rust: QColor = QColor(0xAF593E)
    brown_stone: QColor = QColor(0x593C39)
    brown_sugar: QColor = QColor(0xA17249)
    brownie: QColor = QColor(0x964B00)
    brownish_gray: QColor = QColor(0x86775F)
    brownish_red: QColor = QColor(0x9E3623)
    browns_orange: QColor = QColor(0xFF3C00)
    brunette: QColor = QColor(0x3B1E08)
    bu_scarlet: QColor = QColor(0xCC0000)
    bubblegum: QColor = QColor(0xFFC1CC)
    bubbles: QColor = QColor(0xE7FEFF)
    buff_orange: QColor = QColor(0xF2CA85)
    buff_yellow: QColor = QColor(0xF1BF70)
    bumblebee: QColor = QColor(0xFCE205)
    bumblebee_orange: QColor = QColor(0xFFC82A)
    burgundy: QColor = QColor(0x8D021F)
    burlywood: QColor = QColor(0xDEB887)
    burnt_almond: QColor = QColor(0xB0724A)
    burnt_henna: QColor = QColor(0x7E392F)
    burnt_orange: QColor = QColor(0xCC5500)
    burnt_sienna: QColor = QColor(0xE97451)
    burnt_umber: QColor = QColor(0x8A3324)
    butter: QColor = QColor(0xFFFD74)
    butter_toast: QColor = QColor(0xD2AD84)
    buttercream: QColor = QColor(0xEFE0CD)
    buttermilk: QColor = QColor(0xFDEFB2)
    butterscotch_orange: QColor = QColor(0xD99151)
    buttery_brown: QColor = QColor(0xF1EBDA)
    byzantine_blue: QColor = QColor(0x3457D5)
    byzantium: QColor = QColor(0x702963)
    cadet_gray: QColor = QColor(0x91A3B0)
    cadmium_green: QColor = QColor(0x006B3C)
    cadmium_orange: QColor = QColor(0xE6812F)
    cadmium_red: QColor = QColor(0xE30022)
    cadmium_yellow_lemon: QColor = QColor(0xFFF23E)
    cafe_americano: QColor = QColor(0x362819)
    cafe_au_lait: QColor = QColor(0xA67B5B)
    cafe_noir: QColor = QColor(0x4B3621)
    cake_batter: QColor = QColor(0xF0EDDB)
    calm_orange: QColor = QColor(0xFAB972)
    cambridge_blue: QColor = QColor(0xA3C1AD)
    camel: QColor = QColor(0xC69F59)
    cameo_pink: QColor = QColor(0xEFBBCC)
    camouflage_gray: QColor = QColor(0x545851)
    camouflage_green: QColor = QColor(0x78866B)
    camouflage_yellow: QColor = QColor(0x978942)
    canadian_maple: QColor = QColor(0xCAB266)
    canary_yellow: QColor = QColor(0xFFEF00)
    candy: QColor = QColor(0xD21404)
    candy_apple: QColor = QColor(0xFF0800)
    candy_pink: QColor = QColor(0xE4717A)
    cantaloupe: QColor = QColor(0xFDA172)
    canvas_brown: QColor = QColor(0xBB8855)
    capri_blue: QColor = QColor(0x00BFFF)
    caramel: QColor = QColor(0xAF6F09)
    caramel_apple: QColor = QColor(0xB87A59)
    carbon_black: QColor = QColor(0x0C0A00)
    carbon_gray: QColor = QColor(0x625D5D)
    cardinal: QColor = QColor(0x8A244E)
    cardinal_red: QColor = QColor(0xC41E3A)
    cardinals_red: QColor = QColor(0xBD2031)
    careys: QColor = QColor(0xD8A8A8)
    caribbean_green: QColor = QColor(0x00CC99)
    carmine: QColor = QColor(0x960018)
    carnal_brown: QColor = QColor(0xBB8866)
    carnation: QColor = QColor(0xFFA6C9)
    carnelian_red: QColor = QColor(0xB31B1B)
    carob: QColor = QColor(0x362511)
    carolina_blue: QColor = QColor(0x4B9CD3)
    carolina_plum: QColor = QColor(0x9B84A1)
    carrot: QColor = QColor(0xED7117)
    carrot_orange: QColor = QColor(0xED9121)
    cascading_white: QColor = QColor(0xF7F5F6)
    cashmere: QColor = QColor(0xD1B399)
    castleton_green: QColor = QColor(0x00563B)
    cedar_brown: QColor = QColor(0x4A3728)
    celadon: QColor = QColor(0xACE1AF)
    celeste: QColor = QColor(0xB2FFFF)
    cement_gray: QColor = QColor(0x858A7E)
    ceramic: QColor = QColor(0xFCFFF9)
    cerise_pink: QColor = QColor(0xEC3B83)
    cerise_red: QColor = QColor(0xDE3163)
    cerulean: QColor = QColor(0x0492C2)
    cerulean_blue: QColor = QColor(0x2A52BE)
    cg_red: QColor = QColor(0xE03C31)
    chai: QColor = QColor(0xB1832F)
    chameleon_gray: QColor = QColor(0x686965)
    chamoisee: QColor = QColor(0xA0785A)
    chamomile: QColor = QColor(0xDAC395)
    champagne: QColor = QColor(0xF7E7CE)
    champagne_pink: QColor = QColor(0xF6E1D3)
    charcoal: QColor = QColor(0x36454F)
    charcoal_gray: QColor = QColor(0x232023)
    charleston_green: QColor = QColor(0x232B2B)
    chartreuse: QColor = QColor(0x7FFF00)
    chartreuse_traditional: QColor = QColor(0xDFFF00)
    chateau: QColor = QColor(0x48A860)
    cheese_orange: QColor = QColor(0xFFA600)
    chelsea_blue: QColor = QColor(0x034694)
    cherry_blossom: QColor = QColor(0xFFB7C5)
    cherry_pink: QColor = QColor(0xDE3163)
    cherry_red: QColor = QColor(0x990F02)
    chestnut: QColor = QColor(0xCD5C5C)
    chetwode: QColor = QColor(0xF0FFF0)
    chicory: QColor = QColor(0xA78658)
    chiefs_red: QColor = QColor(0xE31837)
    chiffon: QColor = QColor(0xFFFACD)
    chili_red: QColor = QColor(0xC21807)
    china_rose: QColor = QColor(0xA8516E)
    chinese_green: QColor = QColor(0xD0DB61)
    chinese_orange: QColor = QColor(0xEB6841)
    chinese_violet: QColor = QColor(0x856088)
    chinese_yellow: QColor = QColor(0xFFB200)
    chlorine_blue: QColor = QColor(0x0CAFFF)
    chlorophyll_green: QColor = QColor(0x4AFF00)
    chocolate: QColor = QColor(0x7B3F00)
    chocolate_cosmos_red: QColor = QColor(0x58111A)
    chocolate_orange: QColor = QColor(0xD2691E)
    christmas_green: QColor = QColor(0x00873E)
    chrome: QColor = QColor(0xDBE2E9)
    cider: QColor = QColor(0xB56727)
    cider_orange: QColor = QColor(0xD8A175)
    cincinnati_red: QColor = QColor(0xC6011F)
    cinereous: QColor = QColor(0x98817B)
    cinnabar_red: QColor = QColor(0xE44D2E)
    cinnamon_brown: QColor = QColor(0x652A0E)
    cinnamon_toast: QColor = QColor(0x8D7D77)
    citrine: QColor = QColor(0xE4D00A)
    citrus_brown: QColor = QColor(0xD7C275)
    clay: QColor = QColor(0x80400B)
    cloud: QColor = QColor(0xC5C6D0)
    clover_lime: QColor = QColor(0xFCE883)
    coal: QColor = QColor(0x0C0908)
    cobalt: QColor = QColor(0x1338BE)
    cobalt_blue: QColor = QColor(0x0047AB)
    coconut: QColor = QColor(0xFFF1E6)
    coconut_butter: QColor = QColor(0xF2EFE1)
    coconut_milk: QColor = QColor(0xFFF1E6)
    coconut_white: QColor = QColor(0xE9EDF6)
    coffee: QColor = QColor(0x6F4E37)
    coin: QColor = QColor(0x9897A9)
    coke_red: QColor = QColor(0xF40009)
    cola: QColor = QColor(0xF9EDEB)
    college_navy: QColor = QColor(0x002244)
    columbia_blue: QColor = QColor(0xB9D9EB)
    colza_yellow: QColor = QColor(0xEEB700)
    commercial_white: QColor = QColor(0xEDECE6)
    cool_black: QColor = QColor(0x151922)
    cool_gray: QColor = QColor(0x9090C0)
    copper: QColor = QColor(0xB87333)
    copper_orange: QColor = QColor(0xBB772E)
    copper_red: QColor = QColor(0xD97448)
    copper_rose: QColor = QColor(0x996666)
    coquelicot_red: QColor = QColor(0xFF3800)
    coral: QColor = QColor(0xFF7F50)
    coral_pink: QColor = QColor(0xFE7D6A)
    coral_red: QColor = QColor(0xFF7F50)
    cordovan_red: QColor = QColor(0x893F45)
    corn: QColor = QColor(0xFBEC5D)
    corn_green: QColor = QColor(0x71A92C)
    cornflower_blue: QColor = QColor(0x6495ED)
    cornsilk: QColor = QColor(0xFFF8DC)
    cosmic_latte: QColor = QColor(0xFFF8E7)
    cotton: QColor = QColor(0xFBFBF9)
    cotton_ball: QColor = QColor(0xF2F7FD)
    cotton_candy: QColor = QColor(0xFFBCD9)
    cough_mixture: QColor = QColor(0xF6F4F1)
    crayola_blue: QColor = QColor(0x1F75FE)
    crayola_orange: QColor = QColor(0xFF7538)
    crayola_red: QColor = QColor(0xEE204D)
    crayola_yellow_green: QColor = QColor(0xACDF87)
    cream: QColor = QColor(0xFFFDD0)
    crimson: QColor = QColor(0xB80F0A)
    crocodile: QColor = QColor(0x607D3B)
    croissant: QColor = QColor(0xC4AB86)
    crow: QColor = QColor(0x0D0907)
    cup_cake: QColor = QColor(0xEBF6F7)
    currant: QColor = QColor(0x680C07)
    cyan_blue: QColor = QColor(0x00FFFF)
    cyber_grape_purple: QColor = QColor(0x58427C)
    cyber_yellow: QColor = QColor(0xFFD300)
    cynical_black: QColor = QColor(0x171717)
    daffodil_yellow: QColor = QColor(0xE28D00)
    dahlia_yellow_ral: QColor = QColor(0xF39B1B)
    daisy: QColor = QColor(0xFAFAFA)
    daisy_yellow: QColor = QColor(0xF8DC75)
    dallas_cowboys_blue: QColor = QColor(0x041E42)
    dandelion: QColor = QColor(0xF0E130)
    dark_beige: QColor = QColor(0xAC9362)
    dark_black: QColor = QColor(0x010203)
    dark_blue: QColor = QColor(0x00008B)
    dark_brown: QColor = QColor(0x654321)
    dark_byzantium: QColor = QColor(0x5D3954)
    dark_charcoal: QColor = QColor(0x333333)
    dark_chestnut: QColor = QColor(0x986960)
    dark_chocolate: QColor = QColor(0x2E1503)
    dark_coral: QColor = QColor(0xCD5B45)
    dark_gray: QColor = QColor(0xA9A9A9)
    dark_jungle_green: QColor = QColor(0x1A2421)
    dark_khaki: QColor = QColor(0x9B8F55)
    dark_lemon_lime: QColor = QColor(0x76BA1B)
    dark_magenta: QColor = QColor(0x8B008B)
    dark_moss_green: QColor = QColor(0x4A5D23)
    dark_mulberry: QColor = QColor(0x4C0121)
    dark_olive_green: QColor = QColor(0x556B2F)
    dark_orange: QColor = QColor(0xFF8C00)
    dark_orchid: QColor = QColor(0x9932CC)
    dark_pastel_red: QColor = QColor(0xC23B22)
    dark_pink: QColor = QColor(0xE75480)
    dark_purple: QColor = QColor(0x301934)
    dark_raisin: QColor = QColor(0x1A0F0F)
    dark_red: QColor = QColor(0x8B0000)
    dark_salmon: QColor = QColor(0xE9967A)
    dark_sand: QColor = QColor(0x9F7D4F)
    dark_sapphire: QColor = QColor(0x082567)
    dark_sea_green: QColor = QColor(0x8FBC8F)
    dark_sienna: QColor = QColor(0x3C1414)
    dark_silver: QColor = QColor(0x746D69)
    dark_slate: QColor = QColor(0x3E3D53)
    dark_slate_gray: QColor = QColor(0x2F4F4F)
    dark_spring_green: QColor = QColor(0x177245)
    dark_terra_cotta: QColor = QColor(0xCC4E5C)
    dark_topaz_orange: QColor = QColor(0xEABD8C)
    dark_turquoise: QColor = QColor(0x00CED1)
    dark_vanilla: QColor = QColor(0xD1BEA8)
    dark_violet: QColor = QColor(0x9400D3)
    dark_wood: QColor = QColor(0x855E42)
    dark_yellow: QColor = QColor(0xD5B60A)
    dartmouth_green: QColor = QColor(0x00703C)
    davys_gray: QColor = QColor(0x555555)
    debian_red: QColor = QColor(0xD70A53)
    decorators_white: QColor = QColor(0xECEFEC)
    deep_black: QColor = QColor(0x050203)
    deep_brown: QColor = QColor(0x410200)
    deep_chrome_yellow_ferrario: QColor = QColor(0xFFB045)
    deep_coffee: QColor = QColor(0x704241)
    deep_green: QColor = QColor(0x056608)
    deep_jungle_green: QColor = QColor(0x004B49)
    deep_lilac: QColor = QColor(0xB65FCF)
    deep_magenta: QColor = QColor(0xCC00CC)
    deep_napoli_yellow: QColor = QColor(0xFFCF99)
    deep_pink: QColor = QColor(0xFF1493)
    deep_pruce: QColor = QColor(0xA95C68)
    deep_purple: QColor = QColor(0x524F81)
    deep_ruby_purple: QColor = QColor(0x843F5B)
    deep_saffron: QColor = QColor(0xFFA52C)
    deep_space_sparkle: QColor = QColor(0x4A646C)
    deep_taupe: QColor = QColor(0x7B6660)
    deep_wine: QColor = QColor(0x2C041C)
    deep_yellow: QColor = QColor(0xEACE09)
    deer: QColor = QColor(0xBA8759)
    delft_blue: QColor = QColor(0x1F305E)
    delicate_white: QColor = QColor(0xF1F2EE)
    dell_blue: QColor = QColor(0x0076CE)
    denim: QColor = QColor(0x151E3D)
    denim_blue: QColor = QColor(0x1560BD)
    desert_gray: QColor = QColor(0xB8A487)
    desert_orange: QColor = QColor(0xED8E4A)
    desert_sand_orange: QColor = QColor(0xEDC9AF)
    desire: QColor = QColor(0xEA3C53)
    dijon: QColor = QColor(0xC49102)
    dim_gray: QColor = QColor(0x696969)
    dirt: QColor = QColor(0x9B7653)
    dodgers_blue: QColor = QColor(0x005A9C)
    dollar_bill: QColor = QColor(0x85BB65)
    dolphins_aqua: QColor = QColor(0x008E97)
    dorian_gray: QColor = QColor(0xACA79E)
    dove: QColor = QColor(0x7C6E7F)
    dragon_fire_orange: QColor = QColor(0xFD652D)
    dried_moss: QColor = QColor(0xCCB97E)
    duck_blue: QColor = QColor(0x007791)
    duke_blue: QColor = QColor(0x012169)
    dull_black: QColor = QColor(0x161616)
    dull_brown: QColor = QColor(0x876E4B)
    dull_gray: QColor = QColor(0x8B837E)
    dull_orange: QColor = QColor(0xDB804E)
    dull_purple: QColor = QColor(0x9861A5)
    dull_yellow: QColor = QColor(0xDECA57)
    durian_yellow: QColor = QColor(0xE1BD27)
    dust_storm: QColor = QColor(0xE5CCC9)
    dusty_gray: QColor = QColor(0xB29CA2)
    dusty_orange: QColor = QColor(0xE27A53)
    dusty_yellow: QColor = QColor(0xD4CC9A)
    dutch_orange: QColor = QColor(0xFF9B00)
    dutch_white: QColor = QColor(0xEFDFBB)
    early_bird: QColor = QColor(0xCEA2FD)
    earth_yellow: QColor = QColor(0xE1A95F)
    east_carolina_university_purple: QColor = QColor(0x592A8A)
    ebony: QColor = QColor(0x555D50)
    echo: QColor = QColor(0x898D86)
    ecru: QColor = QColor(0xC2B280)
    eerie_black: QColor = QColor(0x1B1B1B)
    egg_nog: QColor = QColor(0xFAE29C)
    eggplant: QColor = QColor(0x311432)
    eggshell: QColor = QColor(0xF0EAD6)
    egyptian_blue: QColor = QColor(0x1034A6)
    electric_black: QColor = QColor(0x292929)
    electric_blue: QColor = QColor(0x7DF9FF)
    electric_crimson: QColor = QColor(0xFF003F)
    electric_gray: QColor = QColor(0xA5ADAD)
    electric_indigo: QColor = QColor(0x6F00FF)
    electric_lavender: QColor = QColor(0xE39FF6)
    electric_purple: QColor = QColor(0xBF00FF)
    electric_violet: QColor = QColor(0x8F00FF)
    electric_yellow: QColor = QColor(0xFFFF33)
    embassy_purple: QColor = QColor(0x3B343C)
    emerald: QColor = QColor(0x028A0F)
    emerald_green: QColor = QColor(0x50C878)
    eminence: QColor = QColor(0x6C3082)
    empire_yellow: QColor = QColor(0xF7D000)
    english_red: QColor = QColor(0xAB4B52)
    english_violet: QColor = QColor(0x563C5C)
    everton_blue: QColor = QColor(0x003399)
    facebook_blue: QColor = QColor(0x1877F2)
    faded_orange: QColor = QColor(0xCD946A)
    faded_purple: QColor = QColor(0x795F80)
    faded_yellow: QColor = QColor(0xECE3A1)
    fairy_tale: QColor = QColor(0xF2C1D1)
    falcons_red: QColor = QColor(0xA71930)
    fall_harvest: QColor = QColor(0xA78A59)
    falu_red: QColor = QColor(0x801818)
    fandango: QColor = QColor(0xB53389)
    fashion_black: QColor = QColor(0x060403)
    fashion_gray: QColor = QColor(0x8E8D8C)
    fawn: QColor = QColor(0xC8A951)
    feather_brown: QColor = QColor(0xB8AD9E)
    feather_white: QColor = QColor(0xE7EAE5)
    fed_ex_purple: QColor = QColor(0x660099)
    feldgrau: QColor = QColor(0x4D5D53)
    fern: QColor = QColor(0x5DBB63)
    fern_green: QColor = QColor(0x4F7942)
    ferrari: QColor = QColor(0xFF2800)
    fire: QColor = QColor(0xDD571C)
    fire_brick: QColor = QColor(0xB22222)
    fire_engine_red: QColor = QColor(0xCE2029)
    fire_yellow: QColor = QColor(0xFEDE17)
    firewood: QColor = QColor(0xCEBAA8)
    flame: QColor = QColor(0xE34A27)
    flame_red: QColor = QColor(0xE25822)
    flamingo: QColor = QColor(0xFC8EAC)
    flax: QColor = QColor(0xEEDC82)
    flint: QColor = QColor(0x7E7D9C)
    floral_white: QColor = QColor(0xFFFAF0)
    fluorescent_blue: QColor = QColor(0x15F4EE)
    fluorescent_yellow: QColor = QColor(0xCCFF00)
    fog: QColor = QColor(0x655967)
    folly_red: QColor = QColor(0xFF004F)
    ford_blue: QColor = QColor(0x2C3968)
    forest_green: QColor = QColor(0x0B6623)
    fortune_cookie: QColor = QColor(0xE0C5A1)
    fossil: QColor = QColor(0x787276)
    french_beige: QColor = QColor(0xA67B50)
    french_fuchsia: QColor = QColor(0xFD3F92)
    french_gray: QColor = QColor(0xB4B19A)
    french_lime: QColor = QColor(0x9EFD38)
    french_mauve: QColor = QColor(0xD473D4)
    french_pink: QColor = QColor(0xF64A8A)
    french_puce_red: QColor = QColor(0x4E1609)
    frost: QColor = QColor(0xFCFBFC)
    frost_black: QColor = QColor(0x191C20)
    fuchsia: QColor = QColor(0xFF00FF)
    fuchsia_blue: QColor = QColor(0x9C51B6)
    fulvous: QColor = QColor(0xE68000)
    fun: QColor = QColor(0x007848)
    fuzzy_wuzzy_red: QColor = QColor(0xCC6666)
    gainsboro: QColor = QColor(0xDCDCDC)
    gamboge: QColor = QColor(0xE89611)
    garnet: QColor = QColor(0x610C04)
    garnet_red: QColor = QColor(0x733635)
    general_motors_blue: QColor = QColor(0x073980)
    gentle_gray: QColor = QColor(0xDADADA)
    ghost_white: QColor = QColor(0xF8F8FF)
    giants_orange: QColor = QColor(0xFE5A1D)
    gin: QColor = QColor(0xD8E4BC)
    ginger: QColor = QColor(0xB06500)
    ginger_ale: QColor = QColor(0xC9A86A)
    ginger_orange: QColor = QColor(0xB06500)
    gingerbread: QColor = QColor(0x5E2C04)
    girl_scout_green: QColor = QColor(0x00AE58)
    glaucous: QColor = QColor(0x6082B6)
    glaucous_blue: QColor = QColor(0x6082B6)
    glitter: QColor = QColor(0xE6E8FA)
    glossy_black: QColor = QColor(0x252324)
    glossy_gold: QColor = QColor(0xFAE481)
    glossy_gray: QColor = QColor(0xAFADA9)
    glossy_orange: QColor = QColor(0xE78400)
    go_green: QColor = QColor(0x00AB66)
    gold: QColor = QColor(0xFFD700)
    gold_pink: QColor = QColor(0xE6C7C2)
    golden_brown: QColor = QColor(0x996515)
    golden_fog: QColor = QColor(0xF0EAD2)
    golden_gate_bridge_orange: QColor = QColor(0xC0362C)
    golden_poppy: QColor = QColor(0xFCC200)
    golden_yellow_ral: QColor = QColor(0xDD9F00)
    goldenrod: QColor = QColor(0xDAA520)
    goldenrod_orange: QColor = QColor(0xDAA520)
    goldfish_orange: QColor = QColor(0xFF9913)
    good_tax: QColor = QColor(0xC9A0FF)
    gothic_grape: QColor = QColor(0x120321)
    granite: QColor = QColor(0x676767)
    granny_smith_apple: QColor = QColor(0xA8E4A0)
    granola: QColor = QColor(0xD6B85A)
    grape: QColor = QColor(0x663046)
    grape_color: QColor = QColor(0x6F2DA8)
    grapefruit_pink: QColor = QColor(0xE0707C)
    graphite: QColor = QColor(0x594D5B)
    graphite_black_ral: QColor = QColor(0x27292B)
    graphite_gray: QColor = QColor(0x4B4E53)
    gray: QColor = QColor(0x808080)
    gray_brown: QColor = QColor(0x7F7053)
    gray_cloud: QColor = QColor(0xB6B6B4)
    gray_cmyk: QColor = QColor(0x939598)
    gray_dolphin: QColor = QColor(0x5C5858)
    gray_goose: QColor = QColor(0xD1D0CE)
    gray_green: QColor = QColor(0x5E716A)
    gray_owl: QColor = QColor(0xD5D5CD)
    gray_wolf: QColor = QColor(0x504A4B)
    grayish_brown: QColor = QColor(0x7A6A4F)
    grease: QColor = QColor(0x080806)
    greek_orange: QColor = QColor(0xE06E04)
    greek_villa: QColor = QColor(0xF0EBE3)
    green: QColor = QColor(0x3CB043)
    green_lizard: QColor = QColor(0xA7F432)
    green_munsell: QColor = QColor(0x00A877)
    green_screen: QColor = QColor(0x00B140)
    green_yellow: QColor = QColor(0xADFF2F)
    greenish_yellow: QColor = QColor(0xEEEA62)
    gun_smoke_gray: QColor = QColor(0x8A868E)
    gunmetal: QColor = QColor(0x2A3439)
    guppie_green: QColor = QColor(0x00FF7F)
    half_and_half: QColor = QColor(0xFFFFE4)
    halloween_orange: QColor = QColor(0xEE5921)
    harbor_gray: QColor = QColor(0xC7C6C1)
    hardwood: QColor = QColor(0x937A62)
    harlequin: QColor = QColor(0x3FFF00)
    harp: QColor = QColor(0xEBF5F0)
    harvard_crimson: QColor = QColor(0xA51C30)
    hawaiian_brown: QColor = QColor(0x99522C)
    hazel_wood: QColor = QColor(0xC9BB8E)
    hazelnut: QColor = QColor(0xBDA55D)
    heather: QColor = QColor(0x9AA297)
    heavy_brown: QColor = QColor(0x73624A)
    heavy_gray: QColor = QColor(0x050505)
    heliotrope: QColor = QColor(0xDF73FF)
    hibiscus: QColor = QColor(0xB43757)
    hickory: QColor = QColor(0x371D10)
    hippie: QColor = QColor(0xA84860)
    hit: QColor = QColor(0xFFA878)
    hog_bristle_quarter: QColor = QColor(0xEBE4D8)
    hollywood_cerise: QColor = QColor(0xF400A1)
    hollywood_cerise_red: QColor = QColor(0xF400A1)
    honey: QColor = QColor(0xFFC30B)
    honey_brown: QColor = QColor(0xBA9238)
    honey_orange: QColor = QColor(0xFFBD31)
    honeydew: QColor = QColor(0xF0FFF0)
    hookers_green: QColor = QColor(0x49796B)
    hopbush: QColor = QColor(0xD05FAD)
    hot_orange: QColor = QColor(0xFF6E00)
    hot_pink: QColor = QColor(0xFF69B4)
    hot_purple: QColor = QColor(0xA420D0)
    hot_yellow: QColor = QColor(0xFFDA00)
    hunter_green: QColor = QColor(0x355E3B)
    huntington_white: QColor = QColor(0xF1F0E5)
    hunyadi_orange: QColor = QColor(0xE8AC41)
    hunyadi_yellow: QColor = QColor(0xE8AC41)
    husker_red: QColor = QColor(0xE41C38)
    ibm_blue: QColor = QColor(0x0530AD)
    ice_blue: QColor = QColor(0x99FFFF)
    ice_cube: QColor = QColor(0xE3E4E0)
    ice_gray: QColor = QColor(0xBEC3C6)
    iced_coffee: QColor = QColor(0xB18F6A)
    icterine: QColor = QColor(0xFCF75E)
    iguana_green: QColor = QColor(0x71BC78)
    imperial_blue: QColor = QColor(0x005A92)
    imperial_purple: QColor = QColor(0x602F6B)
    imperial_red: QColor = QColor(0xED2939)
    inchworm: QColor = QColor(0xB2EC5D)
    independence_blue: QColor = QColor(0x4C516D)
    india_green: QColor = QColor(0x138808)
    india_saffron: QColor = QColor(0xFF9933)
    indian_red: QColor = QColor(0xCD5C5C)
    indian_yellow: QColor = QColor(0xE3A857)
    indigo: QColor = QColor(0x4B0082)
    indigo_blue: QColor = QColor(0x3F00FF)
    indigo_dye_blue: QColor = QColor(0x00416A)
    ink: QColor = QColor(0x070504)
    ink_black_ral: QColor = QColor(0x212122)
    insolent_purple: QColor = QColor(0x682E3C)
    intel_blue: QColor = QColor(0x0071C5)
    international_klein_blue: QColor = QColor(0x002FA7)
    international_orange: QColor = QColor(0xFF4F00)
    iridium: QColor = QColor(0x3D3C3A)
    iris: QColor = QColor(0x9867C5)
    iris_blue: QColor = QColor(0x5A4FCF)
    irish_green: QColor = QColor(0x009A44)
    irish_orange: QColor = QColor(0xF5883F)
    iron: QColor = QColor(0xA59C94)
    iron_black: QColor = QColor(0x343432)
    isabelline: QColor = QColor(0xF4F0EC)
    island_spice: QColor = QColor(0xFFFCEC)
    ivory: QColor = QColor(0xFFFFF0)
    ivory_black: QColor = QColor(0x231F20)
    jade: QColor = QColor(0x000302)
    jade_green: QColor = QColor(0x00A86B)
    jam: QColor = QColor(0x67032F)
    japanese_carmine: QColor = QColor(0x9D2933)
    japanese_violet_purple: QColor = QColor(0x5B3256)
    jasper_orange: QColor = QColor(0xE89149)
    jasper_red: QColor = QColor(0xD73B3E)
    jazzberry_jam: QColor = QColor(0x67032F)
    jelly_bean_red: QColor = QColor(0xDA614E)
    jet: QColor = QColor(0x343434)
    jet_black: QColor = QColor(0x030303)
    jet_gray: QColor = QColor(0x616D7E)
    john_deere_green: QColor = QColor(0x367C2B)
    jungle_green: QColor = QColor(0x29AB87)
    juniper: QColor = QColor(0x3A5311)
    kaitoke: QColor = QColor(0x004830)
    kalamata: QColor = QColor(0x705160)
    kc_royals_blue: QColor = QColor(0x004687)
    kelly_green: QColor = QColor(0x4CBB17)
    kenyan_copper_red: QColor = QColor(0x7C1C05)
    khaki: QColor = QColor(0xC3B091)
    kikyo_iru: QColor = QColor(0x5D3F6A)
    kingfisher_daisy: QColor = QColor(0x653780)
    knockout_pink: QColor = QColor(0xFF3EA5)
    kobicha: QColor = QColor(0x6B4423)
    koi_orange: QColor = QColor(0xD15837)
    kokushoku: QColor = QColor(0x171412)
    kombu_green: QColor = QColor(0x354230)
    ksu_purple: QColor = QColor(0x512888)
    kurotobi: QColor = QColor(0x351E1C)
    la_salle_green: QColor = QColor(0x087830)
    lace: QColor = QColor(0xF8F2ED)
    lady: QColor = QColor(0xF0C0A8)
    laguna: QColor = QColor(0xF8E473)
    laid_back_gray: QColor = QColor(0xB4AFA9)
    lakers_purple: QColor = QColor(0x552582)
    lamp_black: QColor = QColor(0x2E473B)
    languid_lavender: QColor = QColor(0xD6CADD)
    lapis: QColor = QColor(0x2832C2)
    lapis_blue: QColor = QColor(0x26619C)
    laser_lemon: QColor = QColor(0xFEFE22)
    latte: QColor = QColor(0xC5A582)
    laurel_green: QColor = QColor(0xA9BA9D)
    lava: QColor = QColor(0x808588)
    lava_orange: QColor = QColor(0xF76806)
    lava_red: QColor = QColor(0xCF1020)
    lavender_blush: QColor = QColor(0xFFF0F5)
    lavender_gray: QColor = QColor(0xC4C3D0)
    lavender_rose: QColor = QColor(0xFBA0E3)
    lawn_green: QColor = QColor(0x7CFC00)
    lead: QColor = QColor(0x3F3F4E)
    leather: QColor = QColor(0x0B0705)
    lemon_chiffon: QColor = QColor(0xFFFACD)
    lemon_curry: QColor = QColor(0xCCA01D)
    lemon_yellow: QColor = QColor(0xFDFF00)
    lemonade: QColor = QColor(0xF2DBE7)
    lemonade_crepe: QColor = QColor(0xF2B8C6)
    lexicon: QColor = QColor(0xE7EAEA)
    lexicon_quarter: QColor = QColor(0xF2F2F1)
    liberty_blue: QColor = QColor(0x545AA7)
    licorice: QColor = QColor(0x1A1110)
    light_blush: QColor = QColor(0xF1ABB9)
    light_brick: QColor = QColor(0xFB607F)
    light_brown: QColor = QColor(0xB5651D)
    light_chrome_yellow: QColor = QColor(0xFFCA37)
    light_copper_orange: QColor = QColor(0xF6CBA0)
    light_coral: QColor = QColor(0xF08080)
    light_crimson: QColor = QColor(0xF56991)
    light_deep_pink: QColor = QColor(0xFF5CCD)
    light_goldenrod: QColor = QColor(0xFAFAD2)
    light_gray: QColor = QColor(0xD3D3D3)
    light_gunmetal: QColor = QColor(0x344148)
    light_hot_pink: QColor = QColor(0xFFB3DE)
    light_khaki: QColor = QColor(0xF0E68C)
    light_orange: QColor = QColor(0xFED8B1)
    light_pink: QColor = QColor(0xFFB6C1)
    light_red_ochre: QColor = QColor(0xE97451)
    light_saffron: QColor = QColor(0xFFE797)
    light_salmon: QColor = QColor(0xFDAB9F)
    light_slate_gray: QColor = QColor(0x6D7B8D)
    light_taupe: QColor = QColor(0xB38B6D)
    light_turquoise: QColor = QColor(0xAFEEEE)
    light_yellow: QColor = QColor(0xFFFFE0)
    lightsaber_green: QColor = QColor(0x2FF924)
    lilac: QColor = QColor(0xB65FCF)
    lime: QColor = QColor(0xAEF359)
    lime_green: QColor = QColor(0xC7EA46)
    limerick: QColor = QColor(0x9DC209)
    linen: QColor = QColor(0xF3EAD3)
    link_white: QColor = QColor(0xECF3F9)
    lip_pink: QColor = QColor(0xDBAC98)
    lipstick: QColor = QColor(0x9B1003)
    lipstick_stain: QColor = QColor(0x8E4785)
    liserian_purple: QColor = QColor(0xDE6FA1)
    little_boy_blue: QColor = QColor(0x6CA0DC)
    little_princess: QColor = QColor(0xE9DCE5)
    liver: QColor = QColor(0x534B4F)
    liverpool_red: QColor = QColor(0xC8102E)
    long_distance: QColor = QColor(0x6F456E)
    lovely_purple: QColor = QColor(0x7F38EC)
    lowes_blue: QColor = QColor(0x004792)
    luminous_bright_orange_ral: QColor = QColor(0xFFB700)
    lust_red: QColor = QColor(0xE62020)
    luxury_black: QColor = QColor(0x060D0D)
    luxury_purple: QColor = QColor(0x743089)
    macaroon: QColor = QColor(0xF9E076)
    madder_red: QColor = QColor(0xA50021)
    magenta: QColor = QColor(0xFF00FF)
    magenta_process: QColor = QColor(0xE11584)
    magenta_purple: QColor = QColor(0xA32CC4)
    magic_blue: QColor = QColor(0x0077C0)
    magnolia: QColor = QColor(0xF8F4FF)
    mahogany: QColor = QColor(0xC04000)
    mahogany_orange: QColor = QColor(0xC04000)
    maize_yellow_ral: QColor = QColor(0xDB9100)
    majorelle_blue: QColor = QColor(0x6050DC)
    malachite: QColor = QColor(0x0BDA51)
    manchester_united_red: QColor = QColor(0xDA291C)
    mango_tango: QColor = QColor(0xFB8842)
    mantis: QColor = QColor(0x74C365)
    maple_sugar: QColor = QColor(0xC9A38D)
    maple_syrup: QColor = QColor(0xBB9351)
    mardi_gras: QColor = QColor(0x880085)
    marengo: QColor = QColor(0x4C5866)
    marian_blue: QColor = QColor(0xE1EBEE)
    marigold: QColor = QColor(0xFCB810)
    marigold_orange: QColor = QColor(0xEAA221)
    marmalade: QColor = QColor(0xD16002)
    maroon: QColor = QColor(0x800000)
    mars_brown: QColor = QColor(0xAD6242)
    matte_purple: QColor = QColor(0x392A48)
    matte_silver: QColor = QColor(0xA5A5A8)
    matte_yellow: QColor = QColor(0xEDD94C)
    mauve: QColor = QColor(0xE0B0FF)
    mauveine: QColor = QColor(0x8D029B)
    mauvelous: QColor = QColor(0xEF98AA)
    mavericks_blue: QColor = QColor(0x00538C)
    maximum_green: QColor = QColor(0x4C9A2A)
    maximum_green_yellow: QColor = QColor(0xD9E650)
    maximum_yellow: QColor = QColor(0xFAFA37)
    maya_blue: QColor = QColor(0x73C2FB)
    mecca_orange: QColor = QColor(0xBD5745)
    medium_blue: QColor = QColor(0x0000CD)
    medium_brown: QColor = QColor(0x7F5112)
    medium_gray: QColor = QColor(0xBEBEBE)
    medium_jungle_green: QColor = QColor(0x1C352D)
    medium_orchid: QColor = QColor(0xBA55D3)
    medium_purple: QColor = QColor(0x9370DB)
    medium_purple_3: QColor = QColor(0x8968CD)
    medium_sapphire: QColor = QColor(0x2D5DA1)
    medium_sea_green: QColor = QColor(0x3CB371)
    medium_slate_blue: QColor = QColor(0x7B68EE)
    medium_spring_bud: QColor = QColor(0xC9DC87)
    medium_spring_green: QColor = QColor(0x00FA9A)
    medium_turquoise: QColor = QColor(0x48D1CC)
    medium_vermilion: QColor = QColor(0xCF5B2E)
    medium_vermillion: QColor = QColor(0xD9603B)
    medium_violet_red: QColor = QColor(0xC71585)
    mellow_yellow: QColor = QColor(0xF8DE7E)
    melon: QColor = QColor(0xF7BCAC)
    melon_orange: QColor = QColor(0xDF9166)
    melon_yellow: QColor = QColor(0xFF9C00)
    mercury: QColor = QColor(0xE7E7E7)
    merigold: QColor = QColor(0xFCAE1E)
    merino: QColor = QColor(0xF2EBDD)
    merlot: QColor = QColor(0x541E1B)
    metal: QColor = QColor(0x0E0C0A)
    metallic_gray: QColor = QColor(0xA8A9AD)
    metallic_orange: QColor = QColor(0xE26310)
    metallic_purple: QColor = QColor(0x520E7D)
    metropolis: QColor = QColor(0x1A1A1A)
    mexican_pink: QColor = QColor(0xE4007C)
    middle_green: QColor = QColor(0x4D8C57)
    middle_purple: QColor = QColor(0xD982B5)
    midnight: QColor = QColor(0x2B1B17)
    midnight_green: QColor = QColor(0x004953)
    mikado_yellow: QColor = QColor(0xFFC40C)
    milano: QColor = QColor(0xD95D67)
    milk: QColor = QColor(0xFDFFF5)
    millennium_blue: QColor = QColor(0x002244)
    mimosa: QColor = QColor(0xFFF4BC)
    mimosa_orange: QColor = QColor(0xFFCA4B)
    mineral_yellow: QColor = QColor(0xD39C43)
    minion_yellow: QColor = QColor(0xF5E050)
    mink: QColor = QColor(0x888078)
    mint: QColor = QColor(0x99EDC3)
    mint_cream: QColor = QColor(0xF5FFFA)
    mint_green: QColor = QColor(0x98FB98)
    misty_gray: QColor = QColor(0xBCC2C2)
    misty_rose: QColor = QColor(0xFFE4E1)
    mit_red: QColor = QColor(0xA31F34)
    moccasin: QColor = QColor(0xFFE4B5)
    mocha: QColor = QColor(0x3C280D)
    mojave_desert: QColor = QColor(0xC7B595)
    morning_blue: QColor = QColor(0x8DA399)
    moss: QColor = QColor(0x466D1D)
    moss_green: QColor = QColor(0x8A9A5B)
    mountains_majesty: QColor = QColor(0x9078C0)
    mountbatten_pink: QColor = QColor(0x997A8D)
    mughal_green: QColor = QColor(0x306030)
    mulberry: QColor = QColor(0xC54B8C)
    munsell_blue: QColor = QColor(0x0093AF)
    munsell_purple: QColor = QColor(0x9F00C5)
    munsell_red: QColor = QColor(0xF2003C)
    munsell_yellow: QColor = QColor(0xEFCC00)
    murasaki_purple: QColor = QColor(0x4F284B)
    mustard: QColor = QColor(0xFEDC56)
    muted_yellow: QColor = QColor(0xE0D268)
    myrtle_green: QColor = QColor(0x317873)
    mythical_purple: QColor = QColor(0x53277E)
    nadeshiko_pink: QColor = QColor(0xF6ADC6)
    napier_green: QColor = QColor(0x2A8000)
    nationals_red: QColor = QColor(0xAB0003)
    natural_black: QColor = QColor(0x07000B)
    natural_white: QColor = QColor(0xEEECE6)
    navajo_white: QColor = QColor(0xFFDEAD)
    navy: QColor = QColor(0x0A1172)
    navy_blue: QColor = QColor(0x000080)
    ncs_red: QColor = QColor(0xC40233)
    neon_blue: QColor = QColor(0x4D4DFF)
    neon_fuchsia: QColor = QColor(0xFE4164)
    neon_green: QColor = QColor(0x39FF14)
    neon_orange: QColor = QColor(0xFFAD00)
    neon_pink: QColor = QColor(0xFF6EC7)
    neon_yellow: QColor = QColor(0xCFFF04)
    neutral_black: QColor = QColor(0x0B0B0B)
    neutral_gray: QColor = QColor(0x898E8C)
    nevada: QColor = QColor(0x666A6D)
    new_york_pink: QColor = QColor(0xDD8374)
    nickel: QColor = QColor(0x727472)
    night: QColor = QColor(0x0C090A)
    night_shadow: QColor = QColor(0x1C1C1C)
    night_white: QColor = QColor(0xE1E1DD)
    non_photo_blue: QColor = QColor(0xA4DDED)
    northwestern_purple: QColor = QColor(0x4E2A84)
    nude_pink: QColor = QColor(0xDDC0B4)
    nyanza: QColor = QColor(0xE9FFDB)
    oat: QColor = QColor(0xDFC98A)
    obsidian: QColor = QColor(0x020403)
    ocean: QColor = QColor(0x016064)
    ocean_blue: QColor = QColor(0x009DC4)
    ocean_purple: QColor = QColor(0x6E2D91)
    ochre: QColor = QColor(0xCC7722)
    ochre_orange: QColor = QColor(0xC99700)
    ochre_yellow: QColor = QColor(0xB5904B)
    off_black: QColor = QColor(0x595652)
    office_green: QColor = QColor(0x008000)
    oil: QColor = QColor(0x3B3131)
    oklahoma_crimson: QColor = QColor(0x841617)
    old_burgundy: QColor = QColor(0x43302E)
    old_lace: QColor = QColor(0xFDF5E6)
    old_lavender: QColor = QColor(0x796878)
    old_moss_green: QColor = QColor(0x867E36)
    old_rose: QColor = QColor(0xC08081)
    old_silver: QColor = QColor(0x848482)
    old_wood: QColor = QColor(0xF0EEE4)
    old_yellow: QColor = QColor(0xC8AF55)
    olive: QColor = QColor(0x708238)
    olive_drab: QColor = QColor(0x6B8E23)
    olive_drab_7: QColor = QColor(0x3C341F)
    olive_gray: QColor = QColor(0xA09F8D)
    olive_yellow_ral: QColor = QColor(0x9D8F65)
    onyx: QColor = QColor(0x353839)
    orange: QColor = QColor(0xED7014)
    orange_pale_orange: QColor = QColor(0xFFDFBF)
    orange_paper_orange: QColor = QColor(0xFEE8D6)
    orange_peel: QColor = QColor(0xFF9F00)
    orange_red: QColor = QColor(0xFF4500)
    orange_spice_orange: QColor = QColor(0xD76B00)
    orange_white: QColor = QColor(0xF8F9F5)
    orange_yellow: QColor = QColor(0xFFAD01)
    orchid: QColor = QColor(0xDA70D6)
    orioles_orange: QColor = QColor(0xFB4F14)
    outer_space: QColor = QColor(0x414A4C)
    outrageous_orange: QColor = QColor(0xFF6E4A)
    outrageous_orange_red: QColor = QColor(0xFF6E4A)
    oxblood_red: QColor = QColor(0x800020)
    oxford_blue: QColor = QColor(0x002147)
    oxford_gray: QColor = QColor(0x8391A1)
    oyster: QColor = QColor(0xF0D8D8)
    oyster_white: QColor = QColor(0xE3DFD2)
    pacific_blue: QColor = QColor(0x1CA9C9)
    pacific_pearl: QColor = QColor(0xE8EAE6)
    pakistan_green: QColor = QColor(0x006600)
    palatinate: QColor = QColor(0x72246C)
    pale_goldenrod: QColor = QColor(0xEEE8AA)
    pale_ivory: QColor = QColor(0xFDF6E4)
    pale_lime_yellow: QColor = QColor(0xDFE69F)
    pale_purple: QColor = QColor(0xAA98A9)
    pale_smoke: QColor = QColor(0xCAD4D1)
    pale_violet_red: QColor = QColor(0xDB7093)
    pale_yellow: QColor = QColor(0xFFFFA7)
    panda_black: QColor = QColor(0x3C4748)
    pansy_purple: QColor = QColor(0x78184A)
    pantone_artichoke_green: QColor = QColor(0x4B6F44)
    pantone_blue: QColor = QColor(0x0018A8)
    pantone_orange: QColor = QColor(0xFE5000)
    paolo_veronese_green: QColor = QColor(0x009B7D)
    papaya_whip: QColor = QColor(0xFFEFD5)
    paper_white: QColor = QColor(0xF7FCFE)
    paradise_pink: QColor = QColor(0xE63E62)
    parakeet: QColor = QColor(0x03C04A)
    parchment: QColor = QColor(0xF1E9D2)
    paris_green: QColor = QColor(0x50C878)
    paris_white: QColor = QColor(0xC2D8D3)
    parmesan: QColor = QColor(0xFDE992)
    passion_pink: QColor = QColor(0xCE74A7)
    pastel_black: QColor = QColor(0x1D1C1A)
    pastel_gray: QColor = QColor(0xCCCDC6)
    pastel_orange: QColor = QColor(0xFEBA4F)
    pastel_pink: QColor = QColor(0xFFD1DC)
    pastel_red: QColor = QColor(0xFF6961)
    pastel_yellow: QColor = QColor(0xFFFE71)
    paynes_gray: QColor = QColor(0x40404F)
    peach: QColor = QColor(0xFAD1AF)
    peach_orange: QColor = QColor(0xFFCC99)
    peacock: QColor = QColor(0x022D36)
    peacock_blue: QColor = QColor(0x005F69)
    peanut_brown: QColor = QColor(0x795C34)
    pear: QColor = QColor(0xD1E231)
    pearl: QColor = QColor(0xFBFCF8)
    pearly_purple: QColor = QColor(0xB768A2)
    pebble: QColor = QColor(0x333333)
    pecan: QColor = QColor(0x4A2511)
    penn_blue: QColor = QColor(0x011F5B)
    penn_red: QColor = QColor(0x990000)
    penny: QColor = QColor(0x532915)
    pepper_orange: QColor = QColor(0xE77D22)
    peppermint: QColor = QColor(0xF1F9EC)
    perfect_gray: QColor = QColor(0xA1A1A1)
    periwinkle: QColor = QColor(0xCCCCFF)
    periwinkle_purple: QColor = QColor(0xBE93E4)
    persian: QColor = QColor(0xCA3433)
    persian_blue: QColor = QColor(0x1C39BB)
    persian_green: QColor = QColor(0x00A693)
    persian_orange: QColor = QColor(0xD99058)
    persian_pink: QColor = QColor(0xF77FBE)
    persian_red: QColor = QColor(0xCA3433)
    persian_rose_red: QColor = QColor(0xFE28A2)
    persimmon: QColor = QColor(0xEC5800)
    peru: QColor = QColor(0xCD853F)
    pewter: QColor = QColor(0x696880)
    philippine_orange: QColor = QColor(0xF26E01)
    phillies_red: QColor = QColor(0xE81828)
    phlox: QColor = QColor(0xDF00FF)
    photon_white: QColor = QColor(0xF8F8E8)
    phthalo_blue: QColor = QColor(0x000F89)
    phthalo_green: QColor = QColor(0x123524)
    pickle: QColor = QColor(0x597D35)
    picotee_blue: QColor = QColor(0x2E2787)
    piggy_pink: QColor = QColor(0xFDDDE6)
    pigment_magenta: QColor = QColor(0xFF0090)
    pigment_red: QColor = QColor(0xED1C24)
    pine: QColor = QColor(0x234F1E)
    pine_green: QColor = QColor(0x01796F)
    pine_needle_color: QColor = QColor(0x454D32)
    pink: QColor = QColor(0xF699CD)
    pink_gray: QColor = QColor(0xE7DADA)
    pink_pearl: QColor = QColor(0xE7ACCF)
    pink_salt: QColor = QColor(0xF8EEEC)
    pink_sherbet: QColor = QColor(0xF78FA7)
    pinterest_red: QColor = QColor(0xE60023)
    pistachio: QColor = QColor(0x93C572)
    pitch: QColor = QColor(0x030001)
    pitch_black: QColor = QColor(0x27251F)
    pizza_edge: QColor = QColor(0x9A2CA0)
    platinum: QColor = QColor(0xE5E4E2)
    plum: QColor = QColor(0xDDA0DD)
    polar_bear: QColor = QColor(0xEAE9E0)
    polynesian_blue: QColor = QColor(0x224C98)
    pomelo_white: QColor = QColor(0xF9FFE3)
    pomp_and_power: QColor = QColor(0x86608E)
    pompadour: QColor = QColor(0x720058)
    popstar_red: QColor = QColor(0xBE4F62)
    porcelain: QColor = QColor(0xFFFEFC)
    porpoise: QColor = QColor(0x4D4D5C)
    portland_orange_red: QColor = QColor(0xFF5A36)
    powder: QColor = QColor(0xFBFCFA)
    powder_blue: QColor = QColor(0xB0E0E6)
    power_black: QColor = QColor(0x0E0C01)
    power_gray: QColor = QColor(0x707272)
    premium_black: QColor = QColor(0x100E09)
    prince_charming: QColor = QColor(0x493F5E)
    princeton_orange: QColor = QColor(0xFF8F00)
    prismatic_legacy: QColor = QColor(0xBA1607)
    prismatic_red: QColor = QColor(0xD03D33)
    prismatic_reflections_shade: QColor = QColor(0xFF3C28)
    prismatic_vermilion_renewal: QColor = QColor(0xCA0123)
    prune_red: QColor = QColor(0x701C1C)
    prussian_blue: QColor = QColor(0x003153)
    psg_blue: QColor = QColor(0x004170)
    psychedelic_yellow: QColor = QColor(0xFFF53D)
    puce: QColor = QColor(0xCC8899)
    pullman_green: QColor = QColor(0x3B331C)
    pumpkin: QColor = QColor(0xF5761A)
    pumpkin_orange: QColor = QColor(0xFF7518)
    punch: QColor = QColor(0xF25278)
    pure_orange: QColor = QColor(0xFF8000)
    pure_silver: QColor = QColor(0xC3C7C7)
    purple: QColor = QColor(0xA32CC4)
    purple_4: QColor = QColor(0x551A8B)
    purple_cmyk: QColor = QColor(0x6A317F)
    purple_gray: QColor = QColor(0xA7A6BA)
    purple_heart: QColor = QColor(0x7442C8)
    purple_navy: QColor = QColor(0x4E5180)
    purple_pizzazz: QColor = QColor(0xFE4EDA)
    purple_taupe: QColor = QColor(0x50404D)
    purple_violet: QColor = QColor(0x47243C)
    purpureus: QColor = QColor(0x9A4EAE)
    queen_blue: QColor = QColor(0x436B95)
    radiant_yellow: QColor = QColor(0xFC9E21)
    radical_red: QColor = QColor(0xFF355E)
    radioactive: QColor = QColor(0xFAE500)
    rainbow_yellow: QColor = QColor(0xF5DE10)
    raisin: QColor = QColor(0x290916)
    raisin_black: QColor = QColor(0x242124)
    rajah: QColor = QColor(0xFABA5F)
    raspberry: QColor = QColor(0xD21F3C)
    raspberry_glace: QColor = QColor(0x915F6D)
    raspberry_rose: QColor = QColor(0xB3446C)
    raven: QColor = QColor(0x050301)
    razzle_dazzle_rose: QColor = QColor(0xFF33CC)
    razzmatazz: QColor = QColor(0xE3256B)
    razzmic_berry_purple: QColor = QColor(0x8D4E85)
    real_gold: QColor = QColor(0xE2BF36)
    rebecca_purple: QColor = QColor(0x663399)
    red: QColor = QColor(0xFF0000)
    red_devil: QColor = QColor(0x860111)
    red_fox_orange: QColor = QColor(0x985629)
    red_orange_ral: QColor = QColor(0xB6481C)
    red_sox: QColor = QColor(0xBD3039)
    redwood: QColor = QColor(0xA45A52)
    refresh_black: QColor = QColor(0x111212)
    refresh_yellow: QColor = QColor(0xFFE992)
    regalia_purple: QColor = QColor(0x522D80)
    relax_yellow: QColor = QColor(0xF3E496)
    reseda_green: QColor = QColor(0x6C7C59)
    resolution_blue: QColor = QColor(0x002387)
    retro_black: QColor = QColor(0x1F201F)
    retro_white: QColor = QColor(0xEDEAE2)
    retro_yellow: QColor = QColor(0xF0E27B)
    revere_pewter: QColor = QColor(0xCCC7B9)
    reversed_gray: QColor = QColor(0x080808)
    rhino: QColor = QColor(0xB9BBB6)
    rhythm: QColor = QColor(0x777696)
    rice: QColor = QColor(0xFAF5EF)
    rich_black_fogra29: QColor = QColor(0x010B13)
    rich_gray: QColor = QColor(0x1F2022)
    rifle_green: QColor = QColor(0x444C38)
    ripe_plum: QColor = QColor(0x410056)
    road_sign_green: QColor = QColor(0x01735C)
    roasted_coffee: QColor = QColor(0x4B371C)
    robin_egg_blue: QColor = QColor(0x00CCCC)
    rocket_metallic: QColor = QColor(0x8A7F8D)
    rose: QColor = QColor(0xFC94AF)
    rose_bonbon: QColor = QColor(0xF9429E)
    rose_ebony: QColor = QColor(0x674846)
    rose_gold: QColor = QColor(0xB76E79)
    rose_quartz: QColor = QColor(0xAA98A9)
    rose_red: QColor = QColor(0xC21E56)
    rose_taupe: QColor = QColor(0x905D5D)
    rose_white: QColor = QColor(0xFFFAFA)
    rosewood: QColor = QColor(0x9E4244)
    rosewood_red: QColor = QColor(0x65000B)
    rosy_pink: QColor = QColor(0xFF66CC)
    rouge: QColor = QColor(0xA94064)
    royal_orange: QColor = QColor(0xFF9944)
    royal_periwinkle: QColor = QColor(0xBE93D4)
    royal_yellow: QColor = QColor(0xFADA5E)
    ruber: QColor = QColor(0xCE4676)
    rubine_red: QColor = QColor(0xD10056)
    ruby: QColor = QColor(0xE0115F)
    ruddy_blue: QColor = QColor(0x76ABDF)
    ruddy_pink: QColor = QColor(0xE18E96)
    rufous: QColor = QColor(0xA81C07)
    rufous_red: QColor = QColor(0xA81C07)
    rumba_orange: QColor = QColor(0xF06631)
    russet: QColor = QColor(0x80461B)
    russet_red: QColor = QColor(0x80461B)
    russian_green: QColor = QColor(0x679267)
    russian_violet: QColor = QColor(0x32174D)
    rust: QColor = QColor(0xB7410E)
    rustic_black: QColor = QColor(0x1B1A16)
    rustic_gray: QColor = QColor(0xA6ABA5)
    rustic_orange: QColor = QColor(0xD78C3D)
    rustic_purple: QColor = QColor(0x593163)
    rustic_yellow: QColor = QColor(0xE2C400)
    rusty_red: QColor = QColor(0xDA2C43)
    sable: QColor = QColor(0x060606)
    sacramento_green: QColor = QColor(0x043927)
    saddle_brown: QColor = QColor(0x8B4513)
    safety_orange: QColor = QColor(0xFF6700)
    safety_yellow: QColor = QColor(0xEED202)
    safflower_orange: QColor = QColor(0xFDAE44)
    saffron: QColor = QColor(0xF4C430)
    sage: QColor = QColor(0x728C69)
    sage_gray: QColor = QColor(0xB5BDA5)
    sage_green: QColor = QColor(0x9DC183)
    salamander_orange: QColor = QColor(0xF05E23)
    salmon: QColor = QColor(0xFF9999)
    salmon_orange: QColor = QColor(0xFF8066)
    sand: QColor = QColor(0xF6D7B0)
    sand_dollar: QColor = QColor(0xEDE8BA)
    sandcastle: QColor = QColor(0xDAC17C)
    sandstone: QColor = QColor(0xD67229)
    sandstorm: QColor = QColor(0xECD540)
    sangria: QColor = QColor(0x4D0F28)
    sangria_purple: QColor = QColor(0x4D0F28)
    sangria_red: QColor = QColor(0x5E1916)
    sanguine_red: QColor = QColor(0xBC3F4A)
    sap_green: QColor = QColor(0x507D2A)
    sapphire: QColor = QColor(0x52B2BF)
    sapphire_blue: QColor = QColor(0x0F52BA)
    satin_sheen_gold: QColor = QColor(0xCBA135)
    savoy_blue: QColor = QColor(0x4B61D1)
    scarlet: QColor = QColor(0xFF2400)
    schauss_pink: QColor = QColor(0xFF91AF)
    school_bus_yellow: QColor = QColor(0xFFD800)
    scorpion: QColor = QColor(0x5E5E5E)
    screamin_green: QColor = QColor(0x76FF7A)
    sea: QColor = QColor(0xF09090)
    sea_gray: QColor = QColor(0x9AA2A4)
    sea_green: QColor = QColor(0x2E8B57)
    seafoam: QColor = QColor(0x3DED97)
    seal: QColor = QColor(0x818380)
    seance: QColor = QColor(0x61346B)
    seashell: QColor = QColor(0xFFF5EE)
    seaweed: QColor = QColor(0x354A21)
    selective_yellow: QColor = QColor(0xFFBA00)
    sepia: QColor = QColor(0x704214)
    shades_on: QColor = QColor(0x606060)
    shadow: QColor = QColor(0x373737)
    shadow_white: QColor = QColor(0xEEF1EA)
    shampoo: QColor = QColor(0xFFCFF1)
    shamrock: QColor = QColor(0x03AC13)
    shamrock_green: QColor = QColor(0x009E60)
    sheen_green: QColor = QColor(0x8FD400)
    shimmering_blush: QColor = QColor(0xD98695)
    shiny_purple: QColor = QColor(0xB941FF)
    shocking_pink: QColor = QColor(0xFC0FC0)
    shortbread: QColor = QColor(0xFBE790)
    shrek_green: QColor = QColor(0xC4D300)
    sienna: QColor = QColor(0xA0522D)
    signal_black_ral: QColor = QColor(0x2B2B2C)
    signal_yellow: QColor = QColor(0xF2A900)
    silk_gray: QColor = QColor(0xB6B3A8)
    silver: QColor = QColor(0xC0C0C0)
    silver_chalice: QColor = QColor(0xACACAC)
    silver_pink: QColor = QColor(0xC4AEAD)
    silvery_pink: QColor = QColor(0xDCB5B4)
    simply_white: QColor = QColor(0xEFEDE3)
    sky: QColor = QColor(0x63C5DA)
    sky_blue: QColor = QColor(0xADD8E6)
    slate: QColor = QColor(0x26282A)
    slate_blue: QColor = QColor(0x737CA1)
    slate_gray: QColor = QColor(0x657383)
    slimy_green: QColor = QColor(0x299617)
    smashed_pumpkin: QColor = QColor(0xFD673A)
    smitten: QColor = QColor(0xC84186)
    smoke: QColor = QColor(0x738276)
    smokey_gray: QColor = QColor(0x726E6D)
    smoky_black: QColor = QColor(0x100C08)
    smyrna_purple: QColor = QColor(0xA2627A)
    snapchat_yellow: QColor = QColor(0xFFFC00)
    snow: QColor = QColor(0xF5FEFD)
    snow_drift: QColor = QColor(0xF8FBF8)
    soft_peach: QColor = QColor(0xF6F1F4)
    solid_gray: QColor = QColor(0x979797)
    solid_yellow: QColor = QColor(0xFFE81C)
    sonic_gray: QColor = QColor(0x757575)
    soot: QColor = QColor(0x160D08)
    space_cadet: QColor = QColor(0x1D2951)
    spanish_blue: QColor = QColor(0x0070BB)
    spanish_gray: QColor = QColor(0x989898)
    spanish_orange: QColor = QColor(0xF06105)
    spanish_pink: QColor = QColor(0xF7BFBE)
    spanish_red: QColor = QColor(0xE60026)
    spanish_violet_purple: QColor = QColor(0x4C2882)
    spanish_viridian: QColor = QColor(0x007F5C)
    spanish_yellow: QColor = QColor(0xF9D73D)
    spatial_white: QColor = QColor(0xDEDDDB)
    spectrum_yellow: QColor = QColor(0xFCE517)
    spice: QColor = QColor(0x7A3803)
    spider: QColor = QColor(0x040200)
    spring: QColor = QColor(0xF3F0E8)
    spring_bud: QColor = QColor(0xA7FC00)
    spring_orange: QColor = QColor(0xFD963D)
    spruce: QColor = QColor(0x2C3E4C)
    spruce_blue: QColor = QColor(0x617178)
    squash: QColor = QColor(0xC95B0C)
    squash_orange: QColor = QColor(0xE89362)
    steel: QColor = QColor(0x4682B4)
    steel_blue: QColor = QColor(0x4682B4)
    steel_gray: QColor = QColor(0x888B8D)
    steel_pink: QColor = QColor(0xCC3366)
    stone: QColor = QColor(0x59788E)
    stone_blue: QColor = QColor(0x819EA8)
    stone_eagle: QColor = QColor(0xD8D9DA)
    stone_gray: QColor = QColor(0x928E85)
    stone_white: QColor = QColor(0xFBF6F0)
    storm_gray: QColor = QColor(0xB5BAB6)
    stormcloud: QColor = QColor(0x4F666A)
    stout: QColor = QColor(0x0F0B0A)
    strawberry: QColor = QColor(0xE8888A)
    strong_magenta: QColor = QColor(0xA1045A)
    strong_purple: QColor = QColor(0x875692)
    studio: QColor = QColor(0x7851A9)
    sugar_cookie: QColor = QColor(0xF3EAAF)
    sulfur_yellow: QColor = QColor(0xE8DE35)
    sun_yellow_ral: QColor = QColor(0xEA9300)
    sunflower: QColor = QColor(0xFFDA03)
    sunglow: QColor = QColor(0xFFCC33)
    sunrise_orange: QColor = QColor(0xE67451)
    sunset_orange: QColor = QColor(0xFD5E53)
    sunset_purple: QColor = QColor(0xA865B5)
    sunshine_yellow: QColor = QColor(0xFFFD37)
    super_pink: QColor = QColor(0xCF6BA9)
    swamp: QColor = QColor(0xA8C090)
    swan_white: QColor = QColor(0xFCFCFC)
    sweet_pink: QColor = QColor(0xEE918D)
    syracuse_orange: QColor = QColor(0xD44500)
    syrup: QColor = QColor(0x481F01)
    tacao: QColor = QColor(0x6F3096)
    taffy: QColor = QColor(0xFA86C4)
    tall_ships_blue: QColor = QColor(0x0E81B9)
    tan: QColor = QColor(0xD2B48C)
    tangelo: QColor = QColor(0xFC4C02)
    tangerine: QColor = QColor(0xF78702)
    tangerine_yellow: QColor = QColor(0xFFCC00)
    tango_red: QColor = QColor(0xE4717A)
    tap_shoe: QColor = QColor(0x2A2B2D)
    taupe: QColor = QColor(0x483C32)
    taupe_gray: QColor = QColor(0x8B8589)
    tawny: QColor = QColor(0x80471C)
    tawny_orange: QColor = QColor(0xB25A38)
    tawny_red: QColor = QColor(0xCD5700)
    taxi_cab_yellow: QColor = QColor(0xFDB813)
    tea_bag: QColor = QColor(0x161311)
    tea_green: QColor = QColor(0xD0F0C0)
    tea_rose: QColor = QColor(0xF4C2C2)
    tea_rose_red: QColor = QColor(0xF88379)
    teal: QColor = QColor(0x008080)
    tech_black: QColor = QColor(0x0D0E0E)
    templeton_gray: QColor = QColor(0x788787)
    tender_yellow: QColor = QColor(0xEDEEB7)
    tennis_court_green: QColor = QColor(0x6C935C)
    terracotta: QColor = QColor(0xE2725B)
    terracotta_red: QColor = QColor(0xE2725B)
    thistle: QColor = QColor(0xD8BFD8)
    thulian_pink: QColor = QColor(0xDE6FA1)
    thunder: QColor = QColor(0xBDB7AB)
    thyme: QColor = QColor(0x5EDC1F)
    tickle_me_pink: QColor = QColor(0xFC89AC)
    tiffany_blue: QColor = QColor(0x81D8D0)
    tiger: QColor = QColor(0xFC6A03)
    tiger_orange: QColor = QColor(0xF96815)
    tigers_eye_orange: QColor = QColor(0xE08D3C)
    timberwolf: QColor = QColor(0xDBD7D2)
    titan_white: QColor = QColor(0xEEEEFF)
    titanium_yellow: QColor = QColor(0xEEE600)
    tomato: QColor = QColor(0xFF6347)
    topaz_orange: QColor = QColor(0xFFC87C)
    tornado_cloud: QColor = QColor(0x121213)
    tortilla: QColor = QColor(0x9A7B4F)
    tottenham_navy: QColor = QColor(0x132257)
    tractor_red: QColor = QColor(0xFD0E35)
    traditional_purple: QColor = QColor(0x8E4585)
    traditional_royal_blue: QColor = QColor(0x002366)
    traffic_purple: QColor = QColor(0x913073)
    traffic_yellow_ral: QColor = QColor(0xEFB700)
    transparent_yellow: QColor = QColor(0xF4ECC2)
    tree_sap_orange: QColor = QColor(0xCC7711)
    trombone: QColor = QColor(0xD2B55B)
    tropical_rainforest: QColor = QColor(0x00755E)
    trout: QColor = QColor(0x979788)
    true_black: QColor = QColor(0x0A0B0B)
    true_blue: QColor = QColor(0x2D68C4)
    true_purple: QColor = QColor(0x6A0DAD)
    true_silver: QColor = QColor(0x8A8D8F)
    trust_yellow: QColor = QColor(0xEEBE15)
    tufts_blue: QColor = QColor(0x3E8EDE)
    tulip_pink: QColor = QColor(0xFF8E8E)
    tumbleweed: QColor = QColor(0xDEAA88)
    turkey_red: QColor = QColor(0xA91101)
    turkish_blue: QColor = QColor(0x4F97A3)
    turkish_rose: QColor = QColor(0xB57281)
    turmeric: QColor = QColor(0xF0CA28)
    turquoise: QColor = QColor(0x40E0D0)
    turquoise_blue: QColor = QColor(0x00FFEF)
    turquoise_green: QColor = QColor(0xA0D6B4)
    tuscan_brown: QColor = QColor(0x6F4E37)
    tuscan_red: QColor = QColor(0x7C3030)
    tuscany: QColor = QColor(0xFCD12A)
    twilight_lavender_purple: QColor = QColor(0x8A496B)
    twitter_blue: QColor = QColor(0x1DA1F2)
    tyrian_purple: QColor = QColor(0x66023C)
    ucla_blue: QColor = QColor(0x2774AE)
    ufo_green: QColor = QColor(0x3CD070)
    ultimate_gray: QColor = QColor(0x939597)
    ultra_pink: QColor = QColor(0xFF6FFF)
    ultra_violet: QColor = QColor(0x645394)
    ultramarine_blue: QColor = QColor(0x120A8F)
    umber: QColor = QColor(0x352315)
    university_of_central_arkansas_purple: QColor = QColor(0x4F2D7F)
    university_of_tennessee_orange: QColor = QColor(0xF77F00)
    unmellow_yellow: QColor = QColor(0xFFFF66)
    unresolved_problem: QColor = QColor(0xF3F2ED)
    up_maroon: QColor = QColor(0x7B1113)
    upsdell_red: QColor = QColor(0xAE2029)
    uranian_blue: QColor = QColor(0xAFDBF5)
    urobilin: QColor = QColor(0xE1AD21)
    us_air_force_academy_blue: QColor = QColor(0x004F98)
    us_flag: QColor = QColor(0xBF0A30)
    utah_crimson: QColor = QColor(0xD3003F)
    valentine_pink: QColor = QColor(0xE6A6BE)
    vampire_black: QColor = QColor(0x0F0404)
    vampire_gray: QColor = QColor(0x565051)
    vanilla: QColor = QColor(0xF3E5AB)
    vanilla_ice: QColor = QColor(0xF38FA9)
    venetian_red: QColor = QColor(0xC80815)
    verdun: QColor = QColor(0x487800)
    vermilion: QColor = QColor(0xD74826)
    veronica: QColor = QColor(0xA020F0)
    very_light_malachite_green: QColor = QColor(0x64E986)
    very_pale_yellow: QColor = QColor(0xFFFFBF)
    vibrant_yellow: QColor = QColor(0xFFDA29)
    vintage_gray: QColor = QColor(0x989692)
    vintage_orange: QColor = QColor(0xC9995D)
    vintage_yellow: QColor = QColor(0xCBA92B)
    violet: QColor = QColor(0x8F00FF)
    violet_blue: QColor = QColor(0x324AB2)
    virgin_lust_red: QColor = QColor(0xE4181E)
    viridian: QColor = QColor(0x609078)
    visa_blue: QColor = QColor(0x1A1F71)
    vista_white: QColor = QColor(0xFDFCFA)
    vivid_lime_green: QColor = QColor(0xA4DE02)
    vivid_orange: QColor = QColor(0xFF5E0E)
    vivid_reddish_purple: QColor = QColor(0x870074)
    vivid_sky_blue: QColor = QColor(0x00CCFF)
    vivid_tangelo: QColor = QColor(0xEC7625)
    vivid_white: QColor = QColor(0xF8F8F4)
    vivid_yellow: QColor = QColor(0xFFE302)
    void: QColor = QColor(0x010207)
    volt: QColor = QColor(0xCEFF00)
    vulgar_purple_grape_jelly: QColor = QColor(0x3E2F84)
    wageningen_green: QColor = QColor(0x34B233)
    walnut: QColor = QColor(0x432616)
    walnut_hull: QColor = QColor(0x1B1813)
    warm_black: QColor = QColor(0x004242)
    warm_gray: QColor = QColor(0x6E6259)
    warm_yellow: QColor = QColor(0xF4E98C)
    warriors_blue: QColor = QColor(0x1D428A)
    watermelon: QColor = QColor(0xFC6C85)
    web_orange: QColor = QColor(0xFFA500)
    west_side_orange: QColor = QColor(0xFF9916)
    wet_suit: QColor = QColor(0x080706)
    wheat: QColor = QColor(0xF5DEB3)
    wheat_orange: QColor = QColor(0xF5DEB3)
    white: QColor = QColor(0xFFFFFF)
    white_chocolate: QColor = QColor(0xEDE6D6)
    white_diamond: QColor = QColor(0xE7E8E2)
    white_dove: QColor = QColor(0xF0EFE7)
    white_gray: QColor = QColor(0xF2F3F5)
    white_heat: QColor = QColor(0xFDF9EF)
    white_on_white: QColor = QColor(0xEDEFEF)
    white_sand: QColor = QColor(0xECE9E4)
    white_smoke: QColor = QColor(0xF5F5F5)
    white_whisper: QColor = QColor(0xEAE8E1)
    white_wisp: QColor = QColor(0xE9E9E4)
    whitewash: QColor = QColor(0xFEFFFC)
    wild_orchid: QColor = QColor(0xD470A2)
    wild_strawberry: QColor = QColor(0xFF43A4)
    willpower_orange: QColor = QColor(0xFD5602)
    wind_cave: QColor = QColor(0x1F2024)
    window_gray: QColor = QColor(0x989EA1)
    windsor_tan: QColor = QColor(0xA75502)
    wine: QColor = QColor(0x2C041C)
    wine_dregs_purple: QColor = QColor(0x673147)
    wine_red: QColor = QColor(0x722F37)
    winter_white: QColor = QColor(0xDFDFD5)
    wood: QColor = QColor(0x3F301D)
    wood_brown: QColor = QColor(0xC19A6B)
    woodsmoke: QColor = QColor(0x2B3230)
    x11_gray: QColor = QColor(0xBBBCB6)
    xanadu: QColor = QColor(0x738678)
    xanthic: QColor = QColor(0xEEED09)
    xanthous_orange: QColor = QColor(0xF1B42F)
    yacht_club_black: QColor = QColor(0x222627)
    yale_blue: QColor = QColor(0x00356B)
    yam: QColor = QColor(0xCC5801)
    yam_orange: QColor = QColor(0xE17E45)
    yankees_blue: QColor = QColor(0x0C2340)
    yellow_cmyk: QColor = QColor(0xFFFF00)
    yellow_cream: QColor = QColor(0xEFDC75)
    yellow_jasmine: QColor = QColor(0xCEB00D)
    yellow_orange: QColor = QColor(0xD56F00)
    yellow_pantone: QColor = QColor(0xFEDF00)
    yellow_rose: QColor = QColor(0xFFF000)
    yellow_tan: QColor = QColor(0xFFE36E)
    yin_mn_blue: QColor = QColor(0x2E5090)
    yolk_yellow_pantone: QColor = QColor(0xE2B051)
    young_night: QColor = QColor(0x232323)
    your: QColor = QColor(0xFFC0C0)
    zinc_yellow_ral: QColor = QColor(0xF2CB2E)
    zinnwaldite_brown: QColor = QColor(0x2C1608)
    zombie_gray: QColor = QColor(0x63645E)

ColorTypeVar: TypeAlias = Union[QColor, QRgba64, Any, 
                                Qt.GlobalColor, Colors, 
                                str, int]


from typing import Iterable, Union
from PySide6.QtGui import QDesktopServices
from PySide6.QtCore import QUrl


class LauncheURL:
    @classmethod
    def open_url(cls, *urls: list[Union[str, QUrl]]) -> Iterable[bool]:
        '''
        Web URL      : http, https, ftp, etc...
        File URL     : file:///[file path]
        Map Location : geo:[...],[...]
        Phone Number : tel:[phone number]
        Any URL      : [URL...]
        '''
        for url in urls:
            yield QDesktopServices.openUrl(
                QUrl.fromUserInput(url)
                if isinstance(url, str)
                else url
            )

    ## work on!
    # @classmethod
    # def open_app(cls):
    #     '''
    #     Linux: [.desktop, .AppImage, .boundle, .bin, .sh]
    #     MacOS: [.dmg]
    #     Windows: [.msi, .exe]
    #     '''
    #     ...


class UrlOpen:
    def _open(self, url: Union[str, QUrl]) -> bool:
        return QDesktopServices.openUrl(
            QUrl.fromUserInput(url)
            if isinstance(url, str)
            else url
        )

    @classmethod
    def phone(cls, phone: Union[str, int]) -> bool:
        cls._open(f"tel:{QUrl.fromUserInput(str(phone))}")

    @classmethod
    def tel(cls, tel: Union[str, int]) -> bool:
        cls.phone(tel)

    @classmethod
    def geo(cls, x: Union[str, float], y: Union[str, float]) -> bool:
        cls._open(f"geo:{x},{y}")

    @classmethod
    def url(cls, url: Union[QUrl, str]) -> bool:
        cls._open(url)

    ## work on!
    # @classmethod
    # def app(cls, app: str) -> bool:
    #     ...


#!/usr/bin/python3
# -*- coding: utf-8 -*-

from PySide6.QtWidgets import QListWidgetItem
from ..core import AbstractTool


class ListWidgetItem(AbstractTool, QListWidgetItem):
    def __init__(self, *args, **kwargs):
        QListWidgetItem.__init__(self, *args)
        super().__init__(**kwargs)



#!/usr/bin/python3

from typing import Any


class DuplicateKeyError(Exception):
    def __init__(self, uid: str):
        super().__init__(uid)
        print(f"'{uid}' was registered in this dictionary!")


class _TrackingDec:
    def __init__(self):
        self._instances_dict = dict()

    def _register(self, uid: str, obj: Any) -> None:
        if not isinstance(uid, str):
            raise ValueError("invalid uid, must be str type.")

        if uid in self._instances_dict:
            raise DuplicateKeyError(uid)
        self._instances_dict[uid] = obj

    def _deregister(self, uid: str) -> Any:
        """ deregister widget from manager """
        if not isinstance(uid, str):
            raise ValueError("invalid uid, must be str type.")

        if uid not in self._instances_dict:
            return

        return self._instances_dict.pop(uid)

    def pop(self, uid: str) -> Any:
       self._deregister(uid)

    def get(self, uid: str) -> Any:
        return self._instances_dict.get(uid)

    def items(self) -> Any:
        return self._instances_dict.items()

TrackingDec = _TrackingDec()


class AbstractDec:
    """
    `__init__` method can now return a value

    ### usage example
    ```python
    class Object(AbstractDec):
        def __init__(self, *args, **kwargs) -> object:
            return ...
    ```
    
    #### NOTE: use `uid` parameter to store this class in `TrackingDec`, \
        and call it with Api.fetch
    """

    def __new__(cls, *args, **kwargs) -> Any:
        instance = super().__new__(cls)

        if not hasattr(cls, "objectName"):
            _uid = (kwargs.pop
                    if 'uid' not in
                    instance.__init__.__code__.co_varnames
                    else kwargs.get)("uid", None)

            if _uid is not None:
                TrackingDec._register(_uid, instance)

        return instance.__init__(*args, **kwargs)


class BehaviorDec(AbstractDec):
    pass



#!/usr/bin/python3

from PySide6.QtWidgets import QApplication, QDialog, QWidget
from PySide6.QtCore import QEvent, QObject, QTimer
from PySide6.QtGui import QShowEvent
from ._widget import AbstractWidget


class AbstractDialog(AbstractWidget, QDialog):
    def __init__(self,
                 timeout: float = None,
                 auto_close: bool = False,
                 **kwargs):

        _parent = QApplication.activeWindow()
        if not auto_close:
            _parent.hideEvent = lambda _: self.hide()
            _parent.showEvent = lambda _: self.show()

        QDialog.__init__(self, _parent)
        super().__init__(**kwargs)

        self.window().installEventFilter(self)
        if self._parent is not None:
            self._parent.installEventFilter(self)

        self._timeout = timeout
        self._auto_close = auto_close

    @property
    def _parent(self) -> QWidget:
        return self.parent()

    def showEvent(self, e: QShowEvent) -> None:
        if self.isHidden() or not self.isActiveWindow():
            if self._timeout is not None:
                QTimer.singleShot(self._timeout, self.close)

            super().showEvent(e)
            self.activateWindow()

    def eventFilter(self, arg__1: QObject, arg__2: QEvent) -> bool:
        if arg__1 is self.window():
            if (self._auto_close
                and arg__2.type() in (QEvent.Type.WindowDeactivate, QEvent.Type.Hide)):
                self.close()

        return super().eventFilter(arg__1, arg__2)


#!/usr/bin/python3

from typing import Union
from PySide6.QtWidgets import QGraphicsEffect
from PySide6.QtCore import QTimer, Qt, Signal
from .qstyle_sheet import QStyleSheet
from ._declarative import AbstractDec
from ._base import AbstractBase


class AbstractWidget(AbstractBase):
    long_pressed: Signal = Signal()

    def __init__(self,
                 long_press_delay: int = 1000,
                 effect: QGraphicsEffect = None,
                 qss: Union[str, dict, QStyleSheet] = None,
                 attrs: Union[list[Qt.WidgetAttribute], dict[Qt.WidgetAttribute, bool]] = None,
                 flags: Union[list[Qt.WindowType], dict[Qt.WindowType, bool]] = None,
                 **kwargs):

        self.__long_press_delay: int = long_press_delay

        self.__long_press_timer = QTimer(self)
        self.__long_press_timer.timeout.connect(self.__long_press_timeout)

        self.setMouseTracking(True)
        self.setUpdatesEnabled(True)

        self.setAttribute(Qt.WidgetAttribute.WA_AcceptTouchEvents)

        AbstractBase.__init__(self, **kwargs)

        self._set_qss(
            qss if qss is not None
            else QStyleSheet(qss)
        )

        if effect is not None:
            self._set_effect(effect)

        if attrs is not None:
            self._set_attrs(attrs)

        if flags is not None:
            self._set_flags(flags)

    def _set_effect(self, effect: QGraphicsEffect):
        effect.setParent(self)
        self.setGraphicsEffect(effect)

    def _set_flags(self, flags):
        if isinstance(flags, dict):
            for flag, on in flags.items():
                self.setWindowFlag(flag, on)
        else:
            for flag in flags:
                self.setWindowFlag(flag)

    def _set_attrs(self, attrs: dict):
        if isinstance(attrs, dict):
            for attr, on in attrs.items():
                self.setAttribute(attr, on)
        else:
            for attr in attrs:
                self.setAttribute(attr)

    def _set_qss(self, qss: Union[str, dict, QStyleSheet]):
        self.qss = (QStyleSheet(qss)
                    if isinstance(qss, (str, dict))
                    else qss)
        self.qss._set_parent(self)
        self.qss._set_qss(self.qss._qss)

    def __long_press_timeout(self):
        self.__long_press_timer.stop()
        self.long_pressed.emit()

    def mousePressEvent(self, event):
        self.__long_press_timer.start(self.__long_press_delay)
        return super().mousePressEvent(event)

    def mouseReleaseEvent(self, event):
        self.__long_press_timer.stop()
        return super().mouseReleaseEvent(event)


class WidgetDec(AbstractWidget, AbstractDec):
    pass



#!/usr/bin/python3

from PySide6.QtWidgets import QGraphicsOpacityEffect, QHBoxLayout, QLabel, QWidget
from PySide6.QtCore import QEasingCurve, QPropertyAnimation, Qt
from PySide6.QtGui import QShowEvent
from ...core import AbstractDialog


class SilentDialog(AbstractDialog):
    def __init__(self,
                 *,
                 icon: QWidget,
                 text: QLabel,
                 enable_animation: bool = True,
                 auto_close: bool = True,
                 **kwargs):
        super().__init__(auto_close=auto_close, **kwargs)

        self._enable_animation = enable_animation

        self.setWindowFlags(self.windowFlags() | Qt.WindowType.FramelessWindowHint)
        self.setAttribute(Qt.WidgetAttribute.WA_TranslucentBackground)
        self.setAttribute(Qt.WidgetAttribute.WA_AlwaysStackOnTop)
        self.setWindowOpacity(0.9)

        self.setStyleSheet("""
            QDialog, QWidget {
                padding: 6px;
                border-radius: 12px;
                background-color: #0d0d0d;
                color: #ffffff;
            }
        """)

        self._layout = QHBoxLayout(self)

        icon.setFixedSize(40, 40)

        self._layout.addWidget(icon)
        self._layout.addWidget(text)

        self.setLayout(self._layout)

    def showEvent(self, e: QShowEvent) -> None:
        if self._enable_animation:
            def _finished():
                opacityEffect.deleteLater()
                self.setGraphicsEffect(None)

            opacityEffect = QGraphicsOpacityEffect(self)
            self.setGraphicsEffect(opacityEffect)

            opacityAni = QPropertyAnimation(opacityEffect, b'opacity', self)
            opacityAni.setStartValue(0)
            opacityAni.setEndValue(1)
            opacityAni.setDuration(200)
            opacityAni.setEasingCurve(QEasingCurve.Type.InSine)
            opacityAni.finished.connect(_finished)
            opacityAni.start()

        return super().showEvent(e)


#!/usr/bin/python3

from PySide6.QtWidgets import QSizeGrip
from PySide6.QtGui import QMouseEvent
from PySide6.QtCore import QRect, Qt
from ..services import corner_to_edge
from ..core import AbstractWidget


class WindowSizeGrip(AbstractWidget, QSizeGrip):
    def __init__(self,
                 *,
                 corner: Qt.Corner = Qt.Corner.BottomRightCorner,
                 **kwargs) -> None:
        QSizeGrip.__init__(self)
        super().__init__(**kwargs)

        self._corner = corner
        self.set_cursor_for_position(corner)

    def set_cursor_for_position(self, corner: Qt.Corner):
        self.setCursor({
            Qt.Corner.TopLeftCorner: Qt.CursorShape.SizeFDiagCursor,
            Qt.Corner.TopRightCorner: Qt.CursorShape.SizeBDiagCursor,
            Qt.Corner.BottomLeftCorner: Qt.CursorShape.SizeBDiagCursor,
            Qt.Corner.BottomRightCorner: Qt.CursorShape.SizeFDiagCursor,
        }.get(corner, Qt.CursorShape.ArrowCursor))

    def _move(self) -> None:
        if self.parent() is not None:
            rect: QRect = self.parent().rect()

            if self._corner == Qt.Corner.TopLeftCorner:
                self.move(
                    rect.x(),
                    0
                )

            elif self._corner == Qt.Corner.TopRightCorner:
                x, y = rect.topRight().toTuple()
                self.move(x - (self.width() + 5), y - 5)

            elif self._corner == Qt.Corner.BottomLeftCorner:
                self.move(0, rect.bottom() - self.height())

            elif self._corner == Qt.Corner.BottomRightCorner:
                self.move(rect.right() - self.width() - 1, 
                          rect.bottom() - self.height() - 1)

    def mousePressEvent(self, arg__1: QMouseEvent) -> None:
        self.parent().windowHandle().startSystemResize(corner_to_edge(self._corner))
        return super().mousePressEvent(arg__1)

    def updateGeometry(self) -> None:
        self._move()
        return super().updateGeometry()


#!/usr/bin/python3

import os
import json
import math
from string import Template
from typing import Mapping, Sequence, Union, Any
from PySide6.QtCore import QFile, QPoint, QPointF
from PySide6.QtGui import QColor, QRadialGradient, QLinearGradient


class _QssTemplate(Template):
    delimiter = "--"


class QStyleSheet:
    '''
    :param: qss: 
        - dict: {"background-color": "white"}
        - str : "QWidget { background-color: white; }"
        - str : ":/path/to/resoucre/file.qss",
        - str : "/path/to/local/file.qss"
        - str : "/path/to/local/file.json"

    ## e.g
    Label(
        qss=QStyleSheet(
            qss={
                "background-color": "--themeColor",
                "color": "white",
                "font-size": "24px"
            },
            vars={
                "themeColor": "blue"
            }
        )
    )
    :result:
        QLabel {
            background-color: blue;
            color: white;
            font-size: 24px;
        }

    '''

    class Element:
        def __new__(cls, *args, **kwargs) -> Any:
            instance = super().__new__(cls)
            return instance.__init__(*args, **kwargs)

    class BorderRadius(Element):
        def __init__(self, 
                     top_left: int = 0,
                     top_right: int = 0,
                     bottom_left: int = 0,
                     bottom_right: int = 0) -> str:

            return " ".join(map(lambda x: f"{x}px",
                                (top_left, top_right, bottom_right, bottom_left)))

    class RadialGradient(Element):
        def __init__(self, 
                     stops: Union[Sequence[tuple[float, Union[QColor, str]]], 
                                  dict[float, Union[QColor, str]]],
                     cx: float = None, 
                     cy: float = None,
                     fx: float = None,
                     fy: float = None,
                     radius: float = None,
                     spread: Union[str, QRadialGradient.Spread] = None,
                     coordinate: Union[str, QRadialGradient.CoordinateMode] = None
                     ) -> str:

            if isinstance(spread, QRadialGradient.Spread):
                spread = spread.name.removesuffix("Spread").lower()

            if isinstance(coordinate, QRadialGradient.CoordinateMode):
                coordinate = coordinate.name.removesuffix("Mode")
                coordinate[0] = coordinate[0].lower()

            args = {"cx": cx, "cy": cy, "radius": radius, "fx": fx, "fy": fy, "spread": spread, "coordinateMode": coordinate}
            data = [f"{k}: {v}" for k, v in args.items() if v is not None]
            for value, color in (stops.items() if isinstance(stops, dict) else stops):
                if isinstance(color, QColor):
                    color = f"rgba({','.join(map(str, color.toTuple()))})"
                if value > 1:
                    value = value / 100
                data.append(f"stop: {value} {color}")
            return f"qradialgradient({', '.join(data)})"
    
    class LinearGradient(Element):
        def __init__(self, 
                     stops: Union[Sequence[tuple[float, Union[QColor, str]]], 
                                  dict[float, Union[QColor, str]]],
                     start: Union[QPoint, QPointF] = None, 
                     end: Union[QPoint, QPointF] = None,
                     degree: int = None) -> str:

            data = []
            for value, color in (stops.items() if isinstance(stops, dict) else stops):
                if isinstance(color, QColor):
                    color = f"rgba({','.join(map(str, color.toTuple()))})"
                if value > 1:
                    value = value / 100
                data.append(f"stop: {value} {color}")

            if degree is not None:
                degree = f"x1: {math.cos(degree)}, y1: {math.sin(degree)}, x2: 1, y2: 1"
            else:
                x1, y1, x2, y2 = start.toTuple(), end.toTuple()
                degree = f"x1: {x1}, y1: {y1}, x2: {x2}, y2: {y2}"

            return f"qlineargradient({degree}, {', '.join(data)})"

    class BoxShadow(Element):
        def __init__(self, 
                     x: float,
                     y: float,
                     blur_radius: float,
                     color: Union[QColor, str]):

            if isinstance(color, QColor):
                color = f"rgba({','.join(map(str, color.toTuple()))})"

            return f"{x}px {y}px {blur_radius}px 0px {color}"

    def __init__(self,
                 qss: Union[dict, str],
                 vars: dict = None):

        self._qss = qss
        self._vars = vars
        self._temp = _QssTemplate("")
        self._parent = None

    def _set_parent(self, parent: object):
        self._parent = parent

    def _get_qss_from_str(self, qss: str) -> str:
        if qss.startswith(":") or os.path.exists(qss):
            file = QFile(qss)
            file.open(QFile.OpenModeFlag.ReadOnly)
            data = str(file.readAll(), "utf-8")

            # add .json support
            if qss.lower().endswith(".json"):
                data = self._get_qss_from_dict(json.loads(data))

            file.close()
            return data
        return qss

    def _get_qss_parent(self) -> str:
        _parent = self._parent.objectName().strip()
        if not _parent:
            _parent = self._parent.__class__.__base__.__name__
            return _parent
        return "#" + _parent

    def _get_qss_from_dict(self, qss: dict) -> str:
        style_sheet = ""
        _obj_style = ""

        for k, v in qss.items():
            if isinstance(v, dict) and not k.startswith(":"):
                raise ValueError("Invalid Qss parent!")

            if k.startswith(("#", ".", "*")):
                raise ValueError("Invalid Qss key value!")

            if isinstance(v, dict):
                style_sheet += "%s%s {\n" % (self._get_qss_parent(), k)
                for sk, sv in v.items():
                    style_sheet += f"\t{sk}: {sv};\n"
                style_sheet += "}\n"
            else:
                _obj_style += f"\t{k}: {v};\n"

        style_sheet += "%s {\n" % self._get_qss_parent()
        style_sheet += _obj_style
        style_sheet += "}\n"

        return style_sheet

    def _set_qss(self, qss: Union[dict, str]) -> None:
        if qss:
            _style = (self._get_qss_from_str(qss)
                    if isinstance(qss, str) 
                    else self._get_qss_from_dict(qss))

            if self._vars:
                self._temp.template = _style
                _style = self._temp.safe_substitute(self._vars)

            self._parent.setStyleSheet(_style)

    def update_vars(self, vars: dict) -> None:
        self._vars = vars
        self._set_qss(self._qss)

    def update_qss(self,
                   qss: Union[dict, str],
                   *,
                   save: bool = False) -> None:

        if self._qss is not None:
            if (isinstance(qss, dict) 
                and isinstance(self._qss, dict)):
                _qss = self._qss.copy()
                _qss.update(qss)
                self._qss = qss if save else self._qss
                _style = self._get_qss_from_dict(_qss)
            else:
                self._qss = qss if save else self._qss
                _style = self._get_qss_from_str(qss)
        else:
            _style = (
                self._get_qss_from_dict(qss)
                if isinstance(qss, dict)
                else
                self._get_qss_from_str(qss)
            )

            if save:
                self._qss = qss

        if self._vars:
            self._temp.template = _style
            self._temp.safe_substitute(_style)
            _style = self._temp.safe_substitute(self._vars)

        self._parent.setStyleSheet(_style)

    def restore_qss(self) -> None:
        if self._qss is not None:
            if isinstance(self._qss, dict):
                _style = self._get_qss_from_dict(self._qss)
            else:
                _style = self._get_qss_from_str(self._qss)

            if self._vars:
                self._temp.template = _style
                self._temp.safe_substitute(_style)
                _style = self._temp.safe_substitute(self._vars)

            self._parent.setStyleSheet(_style)
        else:
            self._parent.setStyleSheet("")

    def update(self, 
               qss: Union[dict, str], 
               vars: dict = None, 
               *,
               save: bool = False) -> None:

        if vars is not None:
            self.update_vars(vars)

        self.update_qss(qss, save=save)

    def restore(self) -> None:
        self.restore_qss()

    def style(cls,
              qss: Union[dict, str],
              vars: Mapping[str, object] = None) -> str:
        '''
        :param: qss: 
            - dict: {"background-color": "white"}
            - str : "QWidget { background-color: white; }"
            - str : ":/path/to/resoucre/file.qss",
            - str : "/path/to/local/file.qss"
            - str : "/path/to/local/file.json"
        '''
        if qss:
            _style = (cls._get_qss_from_str(qss)
                      if isinstance(qss, str) 
                      else cls._get_qss_from_dict(qss))
            if vars:
                _temp = _QssTemplate(_style)
                return _temp.safe_substitute(vars)
            return _style


from PySide6.QtWidgets import QWidget, QLayout, QLayoutItem
from PySide6.QtCore import Qt
from typing import Union


class GridLayoutWrapper:
    def __init__(
        self,
        *,
        child: Union[QWidget, QLayout, QLayoutItem],
        row: int,
        col: int,
        rspan: int = 1,
        cspan: int = 1,
        align: Qt.AlignmentFlag = Qt.AlignmentFlag.AlignCenter
    ) -> None:

        self.child = child
        self.row = row
        self.col = col
        self.rspan = rspan
        self.cspan = cspan
        self.align = align


#!/usr/bin/python3

from typing import Optional, Union
from PySide6.QtWidgets import QWidget, QLayout


class FormLayoutWrapper:
    def __init__(
        self,
        row: Optional[Union[QWidget, QLayout]] = None,
        *,
        label: Union[QWidget, str],
        field: Union[QWidget, QLayout]
    ) -> None:

        self.label = label
        self.field = field
        self.row = row


from .caseconverter import CaseConverter
from .boundaries import OnDelimeterLowercaseNext, OnUpperPrecededByLowerAppendLower


class Kebab(CaseConverter):

    JOIN_CHAR = "-"

    def define_boundaries(self):
        self.add_boundary_handler(
            OnDelimeterLowercaseNext(self.delimiters(), self.JOIN_CHAR)
        )
        self.add_boundary_handler(OnUpperPrecededByLowerAppendLower(self.JOIN_CHAR))

    def prepare_string(self, s):
        if s.isupper():
            return s.lower()

        return s

    def mutate(self, c):
        return c.lower()


def kebabcase(s, **kwargs):
    """Convert a string to kebab case

    Example

        Hello World => hello-world

    """
    return Kebab(s, **kwargs).convert()



from typing import Union
from PySide6.QtCore import Qt
from PySide6.QtWidgets import QFrame, QLayout, QScrollArea, QWidget
from ..core import AbstractWidget


class ScrollArea(AbstractWidget, QScrollArea):
    def __init__(self, 
                 *,
                 child: Union[QWidget, QLayout] = None,
                 **kwargs):
        QScrollArea.__init__(self)

        self.setWidgetResizable(True)
        self.setUpdatesEnabled(True)

        self.setAlignment(Qt.AlignmentFlag.AlignCenter)
        self.setSizeAdjustPolicy(QScrollArea.SizeAdjustPolicy.AdjustToContents)

        self.setFrameShape(QFrame.Shape.NoFrame)
        self.setFrameShadow(QFrame.Shadow.Plain)

        super().__init__(**kwargs)

        if child is not None:
            if isinstance(child, QLayout):
                _widget = QWidget()
                child.setProperty("parent", _widget)
                _widget.setLayout(child)
                child = _widget
            self.setWidget(child)


from .wrappers import *
from .qtcore import *
from .qtgui import *

from .icon import Icon
from .movie import Movie
from .color import Color
from .qt_file_open import File
from .settings import Settings
from .ui_loader import UiLoader
from .system_tray import SystemTray
from .size_policy import SizePolicy
from .smooth_scroll import SmoothScroll
from .copy_progress import CopyProgress
from .spacer_item import SpacerItem
from .action import LinePasswordAction, MenuAction
from .media_player import MediaPlayer
from .list_widget_item import ListWidgetItem


#!/usr/bin/python3
# coding:utf-8

from typing import Union
from PySide6.QtWidgets import QGraphicsOpacityEffect, QGridLayout, QHBoxLayout, QSpacerItem, QWidget
from PySide6.QtCore import QEasingCurve, QEvent, QPropertyAnimation, QSize, Qt, QTimer
from PySide6.QtGui import QColor, QIcon, QResizeEvent, QShowEvent
from darkdetect import isDark
from ...core import AbstractDialog
from ...tools import SizePolicy
from ..icon_widget import IconWidget


class MaskDialog(AbstractDialog):
    def __init__(self,
                 *,
                 child: QWidget,
                 mask: QWidget = None,
                 margin: Union[QSize, tuple, int] = 90,
                 enable_animation: bool = True,
                 hide_title_bar: bool = False,
                 fixed_size: bool = False,
                 **kwargs):
        super().__init__(**kwargs)

        self._child = child
        # self._child.closeEvent = lambda e: self.close()

        self._grid_layout = QGridLayout(self)
        self._enable_animation = enable_animation
        self._hide_title_bar = hide_title_bar
        self._fixed_size = fixed_size

        self._margin = self._set_margin(margin)

        if mask is not None:
            self._mask = mask
            self._mask.setParent(self)
        else:
            self._mask = QWidget(self)
            color = QColor(0, 0, 0, 76)
            self._mask.setStyleSheet(f"""
                background: rgba({color.red()}, \
                    {color.blue()}, \
                        {color.green()}, \
                            {color.alpha()})
                            """)
            c = 0 if isDark() else 255
            self._mask.setStyleSheet(f'background: rgba({c}, {c}, {c}, 0.6)')

        self.setWindowFlags(Qt.WindowType.FramelessWindowHint)
        self.setAttribute(Qt.WidgetAttribute.WA_TranslucentBackground)

        if not hide_title_bar and not self._auto_close:
            self.init_title_bar()

        self._grid_layout.addWidget(self._child)
        self._grid_layout.setAlignment(self._child, Qt.AlignmentFlag.AlignCenter)

        self.setGeometry(0, 0, self._parent.width(), self._parent.height())
        self.resize(self._parent.size()) 
        self._mask.resize(self.size())

        if self._auto_close:
            self._mask.mouseReleaseEvent = lambda e: self.close_dialog()

    def _set_margin(self, margin) -> QSize:
        if not isinstance(margin, QSize):
            return QSize(*((margin,) * 2 
                           if isinstance(margin, int) 
                           else margin))
        return margin

    def showEvent(self, e: QShowEvent) -> None:
        if self._enable_animation:
            def _finished():
                opacityEffect.deleteLater()
                self.setGraphicsEffect(None)

            opacityEffect = QGraphicsOpacityEffect(self)
            self.setGraphicsEffect(opacityEffect)

            opacityAni = QPropertyAnimation(opacityEffect, b'opacity', self)
            opacityAni.setStartValue(0)
            opacityAni.setEndValue(1)
            opacityAni.setDuration(200)
            opacityAni.setEasingCurve(QEasingCurve.Type.InSine)
            opacityAni.finished.connect(_finished)
            opacityAni.start()

        super().showEvent(e)

    def _resize_child(self):
        w, h =  max(40, self._margin.width()), max(40, self._margin.height())
        if not self._fixed_size:
            self._child.setFixedSize(self.width() - w, self.height() - h)

    def resizeEvent(self, e):
        self._mask.resize(self.size())
        self._resize_child()

    def eventFilter(self, obj, e: QEvent):
        if self.parent() and obj is self.parent().window():
            if e.type() == QEvent.Type.Resize:
                re = QResizeEvent(e)
                self.resize(re.size())
        return super().eventFilter(obj, e)

    def init_title_bar(self):
        title_bar = QWidget(self)
        title_bar.setSizePolicy(
            SizePolicy(
                horizontal=SizePolicy.Policy.Expanding,
                vertical=SizePolicy.Policy.Fixed
            )
        )

        close_icon = IconWidget(QIcon.fromTheme("window-close"))
        close_icon.setCursor(Qt.CursorShape.PointingHandCursor)
        close_icon.setFixedSize(22, 22)
        close_icon.mousePressEvent = lambda e: self.close_dialog()

        h_layout = QHBoxLayout(title_bar)
        h_layout.setContentsMargins(0, 0, 8, 0)
        h_layout.addSpacerItem(QSpacerItem(0, 0, SizePolicy.Policy.Expanding, SizePolicy.Policy.Fixed))
        h_layout.addWidget(close_icon)

        title_bar.setLayout(h_layout)
        self._grid_layout.addWidget(title_bar)
    
    def close_dialog(self) -> None:
        return QTimer.singleShot(0, self.close)


#!/usr/bin/python3

from ...core import AbstractWidget
from .base import BaseWindow


class MainWindow(AbstractWidget, BaseWindow):
    def __init__(self, **kwargs):
        BaseWindow.__init__(self, **kwargs)
        super().__init__(**kwargs)


#!/usr/bin/python3

import os
import sys
import signal
from typing import Callable, NoReturn, Optional, Sequence, Union
from PySide6.QtCore import QResource, Qt, Signal, qRegisterResourceData
from PySide6.QtWidgets import QApplication, QStyleFactory, QWidget
from PySide6.QtGui import QFontDatabase
from ..core import AbstractQObject


class Application(AbstractQObject, QApplication):
    on_inactive = Signal()
    on_active = Signal()
    on_hidden = Signal()
    on_suspend = Signal()

    def __init__(self,
                 *args,
                 resources: list[Union[str, tuple[Optional[int], bytes, bytes, bytes]]] = None,
                 fonts: list[str] = None,
                 **kwargs):
        QApplication.__init__(self, *args)

        if resources is not None:
            self._set_resources(resources)

        if fonts is not None:
            self._set_fonts(fonts)

        super().__init__(**kwargs)

        self.applicationStateChanged.connect(self._applicationStateChanged)

    def _applicationStateChanged(self, event) -> None:
        if event == Qt.ApplicationState.ApplicationInactive:
            self.on_inactive.emit()
        elif event == Qt.ApplicationState.ApplicationActive:
            self.on_active.emit()
        elif event == Qt.ApplicationState.ApplicationHidden:
            self.on_hidden.emit()
        elif event == Qt.ApplicationState.ApplicationSuspended:
            self.on_suspend.emit()

    def run(self, term_exit: bool = False) -> NoReturn:
        if term_exit:
            signal.signal(signal.SIGINT, signal.SIG_DFL)
        return sys.exit(self.exec())

    def style_list(self) -> list[str]:
        return QStyleFactory.keys()

    def current_style(self) -> str:
        return self.style().name()

    def add_rcc_file(self,
                     rcc_file: str,
                     rcc_root: str = None) -> bool:
        if rcc_root is not None:
            return QResource.registerResource(rcc_file, rcc_root)
        return QResource.registerResource(rcc_file)

    def add_font(self, fontpath: str) -> int:
        return QFontDatabase.addApplicationFont(fontpath)

    def _set_fonts(self, fonts: list[str]):
        for font in fonts:
            if not os.path.exists(font):
                raise FileNotFoundError(f"'{font}' font file not found!")

            self.add_font(fonts)

    def _set_resources(self, resources: list[Union[Callable, tuple[Optional[int], bytes, bytes, bytes]]]):
        '''
        :param: resource
            callable = qInitResources
            tuple = (0x03 | None, qt_resource_struct, qt_resource_name, qt_resource_data)
        '''
        for res in resources:
            if isinstance(res, (tuple, list, set)):
                if len(res) < 4:
                    res = list(res)
                    res.insert(0, 0x03)
                qRegisterResourceData(res[0] if res[0] is not None else 0x03, *res[1:])
            elif callable(res):
                try:
                    res()
                except Exception:
                    ...

    @staticmethod
    def active_window() -> QWidget:
        return QApplication.activeWindow()

    @staticmethod
    def active_modal() -> QWidget:
        return QApplication.activeModalWidget()

    @staticmethod
    def active_popup() -> QWidget:
        return QApplication.activePopupWidget()


class App(Application):
    pass


from PySide6.QtWidgets import QApplication, QWidget
from PySide6.QtCore import QPoint, QObject, QPointF
from PySide6.QtGui import QCursor, QPolygonF
from enum import IntEnum


class _TailPos(IntEnum):
    top = 0
    bottom = 1
    left = 2
    right = 3

    top_left = 4
    top_right = 5

    bottom_left = 6
    bottom_right = 7

    left_top = 8
    left_bottom = 9

    right_top = 10
    right_bottom = 11

    # auto = 12
    none = 13

class _TailDirection(IntEnum):
    center: int = 0
    left: int  = 1
    right: int = 2

    top = left
    bottom = right


class TeachingTipManager(QObject):
    def __init__(self, 
                 direction: _TailDirection = _TailDirection.center,
                 lenght: int = 8):
        super().__init__()

        self.direction = direction
        self.lenght = lenght

    def _direction(self):
        if self.direction == _TailDirection.left:
            return -self.lenght // 2
        elif self.direction == _TailDirection.right:
            return self.lenght // 2
        return 0

    def doLayout(self, tip: QWidget):
        tip._layout.setContentsMargins(0, 0, 0, 0)

    def position(self, tip: QWidget) -> QPoint:
        if not tip._auto_close and not tip.target:
            tip.target = QApplication.activeWindow()

        if tip.target is not None:
            return self._target_pos(tip)

        return self._cursor_pos(tip)

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() - tip.width() // 2, pos.y() + 24)

    @staticmethod
    def make(position: _TailPos):
        managers = {
            _TailPos.top: TopTailTeachingTipManager,
            _TailPos.bottom: BottomTailTeachingTipManager,
            _TailPos.left: LeftTailTeachingTipManager,
            _TailPos.right: RightTailTeachingTipManager,
            _TailPos.top_right: TopRightTailTeachingTipManager,
            _TailPos.bottom_right: BottomRightTailTeachingTipManager,
            _TailPos.top_left: TopLeftTailTeachingTipManager,
            _TailPos.bottom_left: BottomLeftTailTeachingTipManager,
            _TailPos.left_top: LeftTopTailTeachingTipManager,
            _TailPos.left_bottom: LeftBottomTailTeachingTipManager,
            _TailPos.right_top: RightTopTailTeachingTipManager,
            _TailPos.right_bottom: RightBottomTailTeachingTipManager,
            _TailPos.none: TeachingTipManager,
            # _TailPos.auto: AutoTailTeachingTipManager,
        }

        if position not in managers:
            raise ValueError(
                f'`{position}` is an invalid teaching tip position.')
        return managers[position]()


class AutoTailTeachingTipManager(TeachingTipManager):
    """ Auto tail teaching tip manager """

    def doLayout(self, tip):
        ...

    def draw(self, tip, painter):
        ...

    def _cursor_pos(self, tip: QWidget):
        ...

class TopTailTeachingTipManager(TeachingTipManager):
    """ Top tail teaching tip manager """

    def doLayout(self, tip):
        tip._layout.setContentsMargins(0, self.lenght, 0, 0)

    def draw(self, tip, painter):
        w = tip.width()
        painter.drawPolygon(
             QPolygonF([QPointF(w/2 - 7, self.lenght), 
                       QPointF(w/2 + self._direction(), 1),
                       QPointF(w/2 + 7, self.lenght)]))

    def _cursor_pos(self, tip: QWidget):
        '''
        24 = cursor hight
        '''
        pos = QCursor.pos()
        return QPoint(pos.x() - tip.width() // 2,
                      pos.y() + 24)

    def _target_pos(self, tip: QWidget):
        target = tip.target
        pos = target.mapToGlobal(QPoint(0, target.height()))
        x = pos.x() + target.width()//2 - tip.sizeHint().width()//2
        y = pos.y() - tip.layout().contentsMargins().top()
        return QPoint(x, y)


class BottomTailTeachingTipManager(TeachingTipManager):
    """ Bottom tail teaching tip manager """

    def doLayout(self, tip):
        tip._layout.setContentsMargins(0, 0, 0, self.lenght)

    def draw(self, tip, painter):
        w, h = tip.width(), tip.height()
        painter.drawPolygon(
            QPolygonF([QPointF(w/2 - 7, h - self.lenght),
                       QPointF(w/2 + self._direction(), h - 1), 
                       QPointF(w/2 + 7, h - self.lenght)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() - tip.width() // 2,
                      pos.y() - tip.height() - 12)

    def _target_pos(self, tip: QWidget):
        target = tip.target
        pos = target.mapToGlobal(QPoint())
        x = pos.x() + target.width()//2 - tip.sizeHint().width()//2
        y = pos.y() - tip.sizeHint().height() + tip.layout().contentsMargins().bottom()
        return QPoint(x, y)


class LeftTailTeachingTipManager(TeachingTipManager):
    """ Left tail teaching tip manager """

    def doLayout(self, tip):
        tip._layout.setContentsMargins(self.lenght, 0, 0, 0)

    def draw(self, tip, painter):
        h = tip.height()
        painter.drawPolygon(
            QPolygonF([QPointF(self.lenght, h/2 - 7), 
                       QPointF(1, h/2 + self._direction()), 
                       QPointF(self.lenght, h/2 + 7)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() + 12,
                      pos.y() - tip.height() // 2)

    def _target_pos(self, tip: QWidget):
        target = tip.target
        m = tip.layout().contentsMargins()
        pos = target.mapToGlobal(QPoint(target.width(), 0))
        x = pos.x() - m.left()
        y = pos.y() - tip.child.sizeHint().height()//2 + target.height()//2 - m.top()
        return QPoint(x, y)


class RightTailTeachingTipManager(TeachingTipManager):
    """ Left tail teaching tip manager """

    def doLayout(self, tip):
        tip._layout.setContentsMargins(0, 0, self.lenght, 0)

    def draw(self, tip, painter):
        w, h = tip.width(), tip.height()
        painter.drawPolygon(
            QPolygonF([QPointF(w - self.lenght, h/2 - 7), 
                       QPointF(w - 1, h/2 + self._direction()), 
                       QPointF(w - self.lenght, h/2 + 7)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() - tip.width() - 12,
                      pos.y() - tip.height() // 2)

    def _target_pos(self, tip: QWidget):
        target = tip.target
        m = tip.layout().contentsMargins()
        pos = target.mapToGlobal(QPoint(0, 0))
        x = pos.x() - tip.sizeHint().width() + m.right()
        y = pos.y() - tip.child.sizeHint().height()//2 + target.height()//2 - m.top()
        return QPoint(x, y)


class TopLeftTailTeachingTipManager(TopTailTeachingTipManager):
    """ Top left tail teaching tip manager """

    def draw(self, tip, painter):
        painter.drawPolygon(
            QPolygonF([QPointF(20, self.lenght),
                       QPointF(27 + self._direction(), 1),
                       QPointF(34, self.lenght)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() - 27,
                      pos.y() + 24)

    def _target_pos(self, tip: QWidget):
        target = tip.target
        pos = target.mapToGlobal(QPoint(0, target.height()))
        x = pos.x() - tip.layout().contentsMargins().left()
        y = pos.y() - tip.layout().contentsMargins().top()
        return QPoint(x, y)


class TopRightTailTeachingTipManager(TopTailTeachingTipManager):
    """ Top right tail teaching tip manager """

    def draw(self, tip, painter):
        w = tip.width()
        painter.drawPolygon(
            QPolygonF([QPointF(w - 20, self.lenght), 
                       QPointF(w - 27 + self._direction(), 1),
                       QPointF(w - 34, self.lenght)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() - tip.width() + 27,
                      pos.y() + 24)

    def _target_pos(self, tip: QWidget):
        target = tip.target
        pos = target.mapToGlobal(QPoint(target.width(), target.height()))
        x = pos.x() - tip.sizeHint().width() + tip.layout().contentsMargins().left()
        y = pos.y() - tip.layout().contentsMargins().top()
        return QPoint(x, y)


class BottomLeftTailTeachingTipManager(BottomTailTeachingTipManager):
    """ Bottom left tail teaching tip manager """

    def draw(self, tip, painter):
        h = tip.height()
        painter.drawPolygon(
            QPolygonF([QPointF(20, h - self.lenght), 
                       QPointF(27 + self._direction(), h - 1), 
                       QPointF(34, h - self.lenght)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() - 27,
                      pos.y() - tip.height() - 12)

    def _target_pos(self, tip: QWidget):
        target = tip.target
        pos = target.mapToGlobal(QPoint())
        x = pos.x() - tip.layout().contentsMargins().left()
        y = pos.y() - tip.sizeHint().height() + tip.layout().contentsMargins().bottom()
        return QPoint(x, y)


class BottomRightTailTeachingTipManager(BottomTailTeachingTipManager):
    """ Bottom right tail teaching tip manager """

    def draw(self, tip, painter):
        w, h = tip.width(), tip.height()
        painter.drawPolygon(
            QPolygonF([QPointF(w - 20, h - self.lenght), 
                       QPointF(w - 27 + self._direction(), h - 1), 
                       QPointF(w - 34, h - self.lenght)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() - tip.width() + 27,
                      pos.y() - tip.height() - 12)

    def _target_pos(self, tip: QWidget):
        target = tip.target
        pos = target.mapToGlobal(QPoint(target.width(), 0))
        x = pos.x() - tip.sizeHint().width() + tip.layout().contentsMargins().left()
        y = pos.y() - tip.sizeHint().height() + tip.layout().contentsMargins().bottom()
        return QPoint(x, y)


class LeftTopTailTeachingTipManager(LeftTailTeachingTipManager):
    """ Left top tail teaching tip manager """

    def draw(self, tip, painter):
        painter.drawPolygon(
            QPolygonF([QPointF(self.lenght, 10), 
                       QPointF(1, 17 + self._direction()),
                       QPointF(self.lenght, 24)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() + 12,
                      pos.y() - 17)

    def _target_pos(self, tip: QWidget):
        target = tip.target
        m = tip.layout().contentsMargins()
        pos = target.mapToGlobal(QPoint(target.width(), 0))
        x = pos.x() - m.left()
        y = pos.y() - m.top()
        return QPoint(x, y)


class LeftBottomTailTeachingTipManager(LeftTailTeachingTipManager):
    """ Left bottom tail teaching tip manager """

    def draw(self, tip, painter):
        h = tip.height()
        painter.drawPolygon(
            QPolygonF([QPointF(self.lenght, h - 10), 
                       QPointF(1, h - 17 + self._direction()), 
                       QPointF(self.lenght, h - 24)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() + 12,
                      pos.y() - (tip.width() + tip.width() // 2 - 17))

    def _target_pos(self, tip: QWidget):
        target = tip.target
        m = tip.layout().contentsMargins()
        pos = target.mapToGlobal(QPoint(target.width(), target.height()))
        x = pos.x() - m.left()
        y = pos.y() - tip.sizeHint().height() + m.bottom()
        return QPoint(x, y)


class RightTopTailTeachingTipManager(RightTailTeachingTipManager):
    """ Right top tail teaching tip manager """

    def draw(self, tip, painter):
        w = tip.width()
        painter.drawPolygon(
            QPolygonF([QPointF(w - self.lenght, 10), 
                       QPointF(w - 1, 17 + self._direction()),
                       QPointF(w - self.lenght, 24)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() - tip.width() - 12,
                      pos.y() - 17)

    def _target_pos(self, tip: QWidget):
        target = tip.target
        m = tip.layout().contentsMargins()
        pos = target.mapToGlobal(QPoint(0, 0))
        x = pos.x() - tip.sizeHint().width() + m.right()
        y = pos.y() - m.top()
        return QPoint(x, y)

class RightBottomTailTeachingTipManager(RightTailTeachingTipManager):
    """ Right bottom tail teaching tip manager """

    def draw(self, tip, painter):
        w, h = tip.width(), tip.height()
        painter.drawPolygon(
            QPolygonF([QPointF(w - self.lenght, h-10), 
                       QPointF(w - 1, h-17 + self._direction()), 
                       QPointF(w - self.lenght, h-24)]))

    def _cursor_pos(self, tip: QWidget):
        pos = QCursor.pos()
        return QPoint(pos.x() - tip.width() - 12,
                      pos.y() - (tip.width() + tip.width() // 2 - 17))

    def _target_pos(self, tip: QWidget):
        target = tip.target
        m = tip.layout().contentsMargins()
        pos = target.mapToGlobal(QPoint(0, target.height()))
        x = pos.x() - tip.sizeHint().width() + m.right()
        y = pos.y() - tip.sizeHint().height() + m.bottom()
        return QPoint(x, y)


#!/usr/bin/python3

import re
from typing import Union
from random import random
from PySide6.QtCore import Qt
from PySide6.QtWidgets import QApplication, QWidget
from PySide6.QtGui import QColor, QGuiApplication, QLinearGradient, QPixmap, QScreen, QFontMetrics
from ..utils.maths import deg_to_coordinates
from ..core import AbstractDialog


CORNERS = {
    Qt.Corner.TopLeftCorner: Qt.Edge.LeftEdge | Qt.Edge.TopEdge,
    Qt.Corner.TopRightCorner: Qt.Edge.RightEdge | Qt.Edge.TopEdge,
    Qt.Corner.BottomLeftCorner: Qt.Edge.LeftEdge | Qt.Edge.BottomEdge,
    Qt.Corner.BottomRightCorner: Qt.Edge.RightEdge | Qt.Edge.BottomEdge
}


def showDialog(child: AbstractDialog, **kwargs) -> int:
    if kwargs.get("show"):
        return child.show()
    return child.exec()


def TakeScreenShot(*args, **kwargs) -> QPixmap:
    return QGuiApplication.primaryScreen().grabWindow(*args)


def corner_to_edge(corner: Qt.Corner,
                   default: Qt.Edge = Qt.Edge(0)) -> Qt.Edge:

    return CORNERS.get(corner, default)


def edge_to_corner(edge: Qt.Edge,
                   default: Qt.Corner = Qt.Corner.TopLeftCorner) -> Qt.Edge:

    return {v: k for k, v in CORNERS.items()}.get(edge, default)


def center_window(window: QWidget,
                  screen: QScreen = None) -> None:

    dst = screen if screen is not None else QApplication.primaryScreen()
    geo = window.frameGeometry()
    geo.moveCenter(QScreen.availableGeometry(dst).center())
    return window.move(geo.center())


def mixColor(c1: QColor, c2: QColor, weight: float) -> QColor:
    """ mix two color

    Parameters
    ----------
    c1, c2: QColor
        the color to be mixed

    weight: float
        the weight of first color
    """
    return QColor(
        *map(
            lambda color: int(getattr(c1, color)() * weight 
                              + getattr(c2, color)() * (1 - weight)),
            ("red", "green", "blue")
        )
    )

def mixLight(color: QColor, weight: float) -> QColor:
    """ mix color with white

    Parameters
    ----------
    color: QColor
        the color to be mixed

    weight: float
        the weight of `color`
    """
    return mixColor(color, QColor(255, 255, 255), weight)

def mixDark(color: QColor, weight: float) -> QColor:
    """ mix color with black

    Parameters
    ----------
    color: QColor
        the color to be mixed

    weight: float
        the weight of `color`
    """
    return mixColor(color, QColor(0, 0, 0), weight)


def randomColor(alpha: float = 1.0) -> QColor:
    '''Returns a random color (4 tuple).

    :Parameters:
        `alpha`: float, defaults to 1.0
            If alpha == -1, a random alpha value is generated.
    '''
    return QColor(*(random() * 255 for _ in range(3)), 
                  random() * 255 if alpha == -1 else alpha)

def colorToHex(color: Union[tuple[int, int, int], QColor]) -> str:
    '''Transform a rgb(0, 0, 0) color to hex value::
        >>> colorToHex((0, 1, 0))
        '#00ff00'
        >>> colorToHex((25, 77, 90, 5))
        '#3fc4e57f'
        >>> colorToHex(QColor(255, 255, 255))
        '#ffffff'
    '''
    if isinstance(color, QColor):
        return color.name(QColor.NameFormat.HexRgb)
    return '#' + ''.join('{0:02x}'.format(int(x)) for x in color)


def parse_css_linear_gradient(
        css_gradient: str, 
        qt_gradient: QLinearGradient = None,
        *,
        width: int = None,
        apply_deg: bool = False,
        reverse: bool = False) -> QLinearGradient:

    if not qt_gradient:
        if width is not None and apply_deg:
            _deg = int(re.findall(r"(\d+)deg", css_gradient, re.IGNORECASE)[0])
            qt_gradient = QLinearGradient(*deg_to_coordinates(_deg, width))
        qt_gradient = QLinearGradient(0, 0, width if width is not None else 100, 0)

    parts = re.findall(r"[rgb|rgba]\((\d+),\s*(\d+),\s*(\d+),\s*([\d.]+)\) (\d+)%", css_gradient, re.IGNORECASE)
    for index, (*colors, step) in enumerate(parts[::-1] if reverse else parts):
        if reverse:
            step = parts[-index][-1]

        color = QColor(*map(int, colors[:-1] if len(colors) > 3 else colors))
        qt_gradient.setColorAt(float(step) / 100, color)

    return qt_gradient


def parse_css_radial_gradient():
    ...

def parse_css_conic_gradient():
    ...

def eliding_text(text: str, width: int, elide_mode: Qt.TextElideMode = Qt.TextElideMode.ElideRight) -> str:
    return QFontMetrics().elidedText(text, elide_mode, width)


from PySide6.QtWidgets import QFrame
from ..core import AbstractWidget


class Line(AbstractWidget, QFrame):
    def __init__(self, **kwargs):
        QFrame.__init__(self)
        self.setFrameShadow(QFrame.Shadow.Sunken)
        self.setFrameShape(QFrame.Shape.NoFrame)
        super().__init__(**kwargs)


class HLine(Line):
    def __init__(self, **kwargs):
        super().__init__(**kwargs)

        self.setFrameShape(QFrame.Shape.HLine)


class VLine(Line):
    def __init__(self, **kwargs):
        super().__init__(**kwargs)

        self.setFrameShape(QFrame.Shape.VLine)


#!/usr/bin/python3

from PySide6.QtCore import QPropertyAnimation
from PySide6.QtWidgets import QWidget
from ..core import QObjectDec


class PropertyAnimation(QObjectDec, QPropertyAnimation):
    def __init__(self,
                 *,
                 target: QWidget,
                 running: bool = False,
                 **kwargs) -> QWidget:
        QPropertyAnimation.__init__(self)

        self.setTargetObject(target)

        super().__init__(**kwargs)

        if running:
            self.start()

        return target


#!/usr/bin/python3

from typing import Union
from PySide6.QtWidgets import QSizePolicy, QWidget
from ..core import AbstractTool


class SizePolicy(AbstractTool, QSizePolicy):
    def __init__(self,
                 horizontal: QSizePolicy.Policy = None,
                 vertical: QSizePolicy.Policy = None,
                 control_type: QSizePolicy.ControlType = None,
                 stretch: Union[tuple[int, int], int] = None,
                 **kwargs) -> QWidget:
        QSizePolicy.__init__(self)

        if control_type is not None:
            self.setControlType(control_type)

        if horizontal is not None:
            self.setHorizontalPolicy(horizontal)

        if vertical is not None:
            self.setVerticalPolicy(vertical)

        if stretch is not None:
            h, v = (stretch,) * 2 if isinstance(stretch, int) else stretch
            self.setHorizontalStretch(h)
            self.setVerticalStretch(v)

        super().__init__(**kwargs)


from typing import Union
from PySide6.QtCore import QRect, QSize, Qt
from PySide6.QtWidgets import (
    QLayout,
    QLayoutItem,
    QWidget,
    QWidgetItem,
)
from ..enums.position import Positions
from ..enums.size import Sizes
from ..core import AbstractQObject
from ..tools.wrappers.border_layout import BorderLayoutWrapper


class _BorderLayout(QLayout):
    def __init__(self):
        super().__init__()

        self._list: list[BorderLayoutWrapper] = []

    def __del__(self):
        item = self.takeAt(0)
        while item:
            item = self.takeAt(0)

    def addItem(self, 
                item: QLayoutItem, 
                position: Positions = Positions.left):

        self.add(item, position)

    def addWidget(self, widget: QWidget, position: Positions = Positions.left):
        super().addWidget(widget)
        self.add(QWidgetItem(widget), position)

    def add_item_wrapper(self, item: BorderLayoutWrapper):
        self._list.append(item)

    def expandingDirections(self) -> Qt.Orientation:
        return Qt.Orientation.Horizontal | Qt.Orientation.Vertical

    def hasHeightForWidth(self) -> bool:
        return False

    def count(self) -> int:
        return len(self._list)

    def itemAt(self, index: int) -> QLayoutItem:
        if index < len(self._list):
            wrapper: BorderLayoutWrapper = self._list[index]
            return wrapper.item
        return None

    def minimumSize(self) -> QSize:
        return self.calculate_size(Sizes.minimum)

    def setGeometry(self, rect: QRect):
        center: BorderLayoutWrapper = None
        east_width = 0
        west_width = 0
        north_height = 0
        south_height = 0

        super().setGeometry(rect)

        for wrapper in self._list:
            item: QLayoutItem = wrapper.item
            position: Positions = wrapper.pos

            if position == Positions.top:
                item.setGeometry(
                    QRect(
                        rect.x(), north_height, rect.width(), item.sizeHint().height()
                    )
                )

                north_height += item.geometry().height() + self.spacing()

            elif position == Positions.bottom:
                item.setGeometry(
                    QRect(
                        item.geometry().x(),
                        item.geometry().y(),
                        rect.width(),
                        item.sizeHint().height(),
                    )
                )

                south_height += item.geometry().height() + self.spacing()

                item.setGeometry(
                    QRect(
                        rect.x(),
                        rect.y() + rect.height() - south_height + self.spacing(),
                        item.geometry().width(),
                        item.geometry().height(),
                    )
                )

            elif position == Positions.center:
                center = wrapper

        center_height = rect.height() - north_height - south_height

        for wrapper in self._list:
            item: QLayoutItem = wrapper.item
            position: Positions = wrapper.pos

            if position == Positions.left:
                item.setGeometry(
                    QRect(
                        rect.x() + west_width,
                        north_height,
                        item.sizeHint().width(),
                        center_height,
                    )
                )

                west_width += item.geometry().width() + self.spacing()

            elif position == Positions.right:
                item.setGeometry(
                    QRect(
                        item.geometry().x(),
                        item.geometry().y(),
                        item.sizeHint().width(),
                        center_height,
                    )
                )

                east_width += item.geometry().width() + self.spacing()

                item.setGeometry(
                    QRect(
                        rect.x() + rect.width() - east_width + self.spacing(),
                        north_height,
                        item.geometry().width(),
                        item.geometry().height(),
                    )
                )

        if center:
            center.item.setGeometry(
                QRect(
                    west_width,
                    north_height,
                    rect.width() - east_width - west_width,
                    center_height,
                )
            )

    def sizeHint(self) -> QSize:
        return self.calculate_size(Sizes.hint)

    def takeAt(self, index: int):
        if 0 <= index < len(self._list):
            layout_struct: BorderLayoutWrapper = self._list.pop(index)
            return layout_struct.item
        return None

    def add(self, item: QLayoutItem, position: Positions):
        self._list.append(BorderLayoutWrapper(item, position))

    def calculate_size(self, size_type: Sizes):
        total_size = QSize()

        for wrapper in self._list:
            position = wrapper.pos

            item_size: QSize
            if size_type == Sizes.minimum:
                item_size = wrapper.item.minimumSize()
            elif size_type == Sizes.maximum:
                item_size = wrapper.item.maximumSize()
            else:
                item_size = wrapper.item.sizeHint()

            if position in (Positions.top, Positions.bottom, Positions.center):
                total_size.setHeight(total_size.height() + item_size.height())

            if position in (Positions.left, Positions.right, Positions.center):
                total_size.setWidth(total_size.width() + item_size.width())

        return total_size

    def wrapper(self, 
                child: QWidget | QLayoutItem, 
                pos: Positions = Positions.left) -> BorderLayoutWrapper:

        return BorderLayoutWrapper(child, pos)


class BorderLayout(AbstractQObject, _BorderLayout):
    def __init__(self, 
                 children: list[Union[QWidget, 
                                      QLayoutItem, 
                                      BorderLayoutWrapper]] = None,
                 **kwargs):
        _BorderLayout.__init__(self)
        super().__init__(**kwargs)

        if not children:
            return

        for child in children:
            if isinstance(child, BorderLayoutWrapper):
                self.add_item_wrapper(child)

            elif isinstance(child, QLayoutItem):
                self.addItem(child)

            elif isinstance(child, QWidget):
                self.addWidget(child)


#!/usr/bin/python3

from PySide6.QtCore import QSequentialAnimationGroup, QAbstractAnimation
from PySide6.QtWidgets import QWidget
from ..core import QObjectDec


class SequentialAnimationGroup(QObjectDec, QSequentialAnimationGroup):
    def __init__(self,
                 *,
                 target: QWidget,
                 children: list[QAbstractAnimation] = None,
                 running: bool = False,
                 **kwargs) -> QWidget:
        QSequentialAnimationGroup.__init__(self)
        super().__init__(**kwargs)

        for child in children:
            child.setTargetObject(target)
            self.addAnimation(child)

        if running:
            self.start()

        return target


#!/usr/bin/python3
# -*- coding: utf-8 -*-

from typing import Union
from PySide6.QtWidgets import QWidget, QLayout, QGroupBox
from ..core import AbstractWidget


class GroupBox(AbstractWidget, QGroupBox):
    def __init__(self, 
                 *, 
                 child: Union[QWidget, QLayout], 
                 **kwargs):
        QGroupBox.__init__(self)
        super().__init__(**kwargs)

        if isinstance(child, QLayout):
            child.setProperty("parent", self)
            self.setLayout(child)
        else:
            child.setParent(self)